#=============================================================================
# check.def contains the tests, error thresholds, short warning messages
#   and text offering some explanation and advise issued by
#      the program PLATON when run in the 'VALIDATION' mode
#
#           This file is read when PLATON is called with the '-u' switch
#                    (e.g. 'platon -u sk1500.cif')
#
#   The file check.def should either be in the directory where the program
#   is run or specified with the environment variable CHECKDEF
#                  (e.g. setenv CHECKDEF /mnt/user/checkdef)
# 
# - Validation output will be in the order as defined implicitly below
#
# - Tests are identified with three-digit numbers
#   _0xx - general
#   _1xx - cell/symmetry
#   _2xx - adp-related
#   _3xx - intra geometry
#   _4xx - inter geometry
#   _5xx - coordination geometry
#   _6xx - void tests
#   _7xx - varia
#   _8xx - (Fatal) Software Errors/Problems
#   _9xx - Reflection data issues
#
# - All tests are defined as two line stanzas
#   The first line gives the test-number and thresholds (A4, 3A5)
#      E.g. _klm crit_1 crit_2 crit_3
#   The second line defines the message (A55).
#      E.g. 'Structure contains solvent accessible Voids of $F A**3'
#
#   $I defines where (optionally) an 'integer' threshold/value will be placed 
#   $F defines where (optionally) a 'real' threshold/value will be placed 
#   $A defines where an atom label is inserted (first)
#   $B defines where an atom label is inserted (second)
#   $X defines where bond,angle,torsion (calculated) is inserted
#   $Y defines where bond,angle,torsion (reported)   is inserted
#
# Tests (value > crit) are done from right to left (ie crit_3 crit_2 crit_1)
#
# ALERT_Level_A = Could Indicate a Serious Problem - Consider Carefully.
# ALERT_Level_B = Might Indicate a Potentially Serious Problem.
# ALERT_Level_C = Check to Ensure it is OK and not Because of an Oversight.
# ALERT_Level_G = General Info. Check that it is not Something Unexpected.
#
# ALERT_Type_1  = CIF Construction/Syntax Error, Inconsistent or Missing Data.
# ALERT_Type_2  = Indicator that the Structure Model may be Wrong or Deficient.
# ALERT_Type_3  = Indicator that the Structure Quality may be Low.
# ALERT_Type_4  = Cosmetic improvement, Methodology, Query or Suggestion.
# ALERT_Type_5  = Informative Message, Check.
#
# NOTES: - Validation runs invoked with the '-u' option will provide textual 
#          information and HELP on the reported ALERTS (and -U without)
#        - The -G option provides for 'Chem-Mode' (i.e. without Acta 
#          specific ALERTS)
#        - Actual ALERTS start at _002 (Others are pseudo ALERTS)
#        - Coding on criteria line: A = All, I = IUCr only, O = Obsolete
#        - Four numbers (0 or 1) indicate (and used for counting) respectively 
#          - Missing Experimental Info Issues
#          - Experimental Data Related Issues
#          - Structural Model Related Issues
#          - Unresolved or to be Checked Issues 
#============================================================================= 
# >>> Definition of Notification Levels (4A8)    (Pseudo ALERT)
_000                  A   0 0 0 0
ALERT_G ALERT_C ALERT_B ALERT_A 
#=============================================================================
# >>> Listing header on file *.chk               (Pseudo ALERT)
_001                  A   0 0 0 0
# PLATON/CHECK-(------) versus check.def version of 071014
#=============================================================================
# >>> Report number of atom sites with distance/angle restraints
_002    0    0    0 2 A   0 0 1 0
Number of Distance or Angle Restraints on AtSite $I Note     

 This ALERT reports the number of atomic sites that are flagged as distance
 or angle restrained (D-Flag)
#=============================================================================
# >>> Report number of non-H atoms with Uiso or Uij restraints
_003    0    0    0 2 A   0 0 1 0
Number of Uiso or Uij Restrained non-H Atoms ... $I Report

 This ALERT reports the number of non-H atoms that are flagged as handled 
 with Uiso or Uij restraints (U-Flag)
#=============================================================================
# >>> Report Dimensionality of polymer
_004    0    0    0 5 A   0 0 0 0 
Polymeric Structure Found with Maximum Dimension $I Info

 This ALERT reports on polymeric networks and their dimensionality as found in
 the crystal structure. 
 Note: Polymeric structures can be legitimate or due to an erroneous 
 structure analysis.    
#=============================================================================
# >>> Check for refinement instruction file 
_005    0    0    0 5 A   1 0 0 0
No _iucr_refine_instructions_details  in the CIF     Please Do ! 

 No 'refinement details' record was found. Acta Cryst. requires the 
 inclusion of the last shelxl.res file (in case of a SHELXL or XL refinement)
 in the CIF embedded between records with semicolons in position 1, preceded
 by an '_iucr_refine_instructions_details' record.

 Note: SHELXL2014 will automatically include the final .res as an embedded
 comment with the dataname '_shelx_res_file'. 
#=============================================================================
# >>> Check for Extinction parameter refinement   
_006    0    0    0 5 A   0 0 0 0 
Note: Extinction Parameter Refined  = $A             ! Info

 This ALERT reports the refinement of an extinction parameter.
 SHELXL corrects Fobs values in the FCF for Extinction. JANA not.   
#=============================================================================
# >>> Report on unrefined D-H atoms                              
_007    0    0    0 5 A   0 0 1 0
Number of Unrefined Donor-H Atoms .............. $I Report

 It is standard practice to refine Hydrogen atoms on hetero atoms as
 proof of their correct assignment.
#=============================================================================
# >>> Check for refinement reflections details
_008    0    0    0 5 A   1 0 0 0
No _iucr_refine_reflections_details   in the CIF     Please Do !

 No reflection records were found in the CIF. Acta Cryst. will soon require
 the inclusion of the reflection file used in the final refinement 
 (shelxl.hkl in case of a SHELXL or XL refinement) in the CIF, embedded 
 between records with semicolons in position 1 and preceded by an 
 '_iucr_refine_instructions_details' record. 

 Note: SHELXL2014 will automatically include the .hkl as an embedded
 comment with the dataname '_shelx_hkl_file'. 
#=============================================================================
# >>>                                                           
_009    0    2    2 1 A   0 0 0 1
Reported radiation_type and wavelength differ .      Please Check

 The reported values for _diffrn_radiation_type and 
 _diffrn_radiation_wavelength should be consistent.
#=============================================================================
# >>> Test for Reflection Data for Validation and Archival                      
_010    0    0    0 1 A   1 0 0 0 
No Suitable (Embedded) Reflection Data Supplied      Please Do ! 

 Validation is not complete without the availability of the diffraction data.
 Deposited reflection data are preferably the set of reflections that were
 used in the final refinement and embedded in the CIF between records with
 semicolons in position 1 and preceded by an _iucr_refine_instructions_details
 record.  SHELXL2014 will do that automatically. Alternatively, an external
 file with final observed, calculated and sigma reflection data will be the
 minimum for validation and archival. 
#=============================================================================
# >>> Test for any ATOMS found in CIF                           
_011    0    0    0 1 A   0 0 0 0
No atoms found in the supplied CIF ............      Please Check 

 No atom coordinates were detected in the CIF prior to the U(i,j) loop.
#=============================================================================
# >>> Check for _shelx_res_checksum                               
_012    0    0    0 1 A   1 0 0 0
No _shelx_res_checksum found in CIF...........       Please Check
  
 The CIF contains a _shelx_res_file record but not an associate
 _shelx_res_checksum record.
#=============================================================================
# >>> Check for _shelx_hkl_checksum                             
_013    0    0    0 1 A   1 0 0 0
No _shelx_hkl_checksum found in CIF...........       Please Check

 The CIF contains a _shelx_hkl_file record but not an associate
 _shelx_hkl_checksum record.  
#=============================================================================
# >>> Check for _shelxl_fab_checksum
_014    0    0    0 1 A   1 0 0 0
No _shelx_fab_checksum found in CIF...........       Please Check
  
 The CIF contains a _shelx_fab_file record but not an associate
 _shelx_fab_checksum record. 
#=============================================================================
# >>> Check for refinement reflections details (SHELXL20xy)
_015    0    0    0 5 A   1 0 0 0
No _shelx_hkl_file record in SHELXL20xy CIF ...      Please Do !

 No embedded reflection record was found in the CIF file that was created with
 SHELXL20xy (or XL). SHELXL20xy automatically includes the '.hkl' file that
 was used in the refinement (along with the final '.res' file) as an embedded
 comment with the dataname '_shelx_hkl_file'. Do not change this dataname
 in _iucr_refine_reflections_details. Such a record is useful for archival 
 and follow-up calculations. 
#=============================================================================
# >>> Check for refinement FAB file (SHELXL20xy)
_016    0    0    0 5 A   1 0 0 0
No _shelx_fab_file record in SHELXL20xy CIF ...      Please Supply

 No embedded .fab record was found in the CIF file that was created with
 SHELXL20xy (or XL). SHELXL20xy automatically includes the '.fab' file that
 was used in the refinement (along with the final '.res' & '.hkl' files) as
 an embedded comment with the dataname '_shelx_fab_file'. Do not change this
 dataname. Such a record is useful for archival and follow-up calculations. 
#=============================================================================
# >>> Check the Consistency of Scattering Type
_017 0.00 0.00 0.00 1 A   0 0 1 0                   
Check Consistency of Scattering Type $B for        $A

 Check for the correct scattering type assignment to this atom. 
#=============================================================================
# >>> Check _diffrn_measured_fraction_theta_max and full identical 
_018 0.00 0.00 2.00 1 A   0 0 0 0     
 _diffrn_measured_fraction_theta_max .NE. _full           ! Check 

 The reported value of _diffrn_measured_fraction_theta_full is not equal to 
 the reported value of _diffrn_measured_fraction_theta_max with 
 _diffrn_reflns_theta_max and _diffrn_reflns_theta_full reported as equal.    
#=============================================================================
# >>> Check _diffrn_measured_fraction_theta_max/full consistency
_019 0.00 0.02 1.00 1 A   0 1 0 0     
 _diffrn_measured_fraction_theta_full/_max < 1.0 $F Report

 The reported value of _diffrn_measured_fraction_theta_full is less than
 the reported value of _diffrn_measured_fraction_theta_max. Their ratio is
 reported when less than 1.0. When theta_full is less than theta_max such
 a value indicates that there are relatively more reflections missing at
 lower resolution. 
#=============================================================================
# >>> Check Rint                                  
_020 0.12 0.18 0.25 3 A   0 1 0 0     
The value of Rint is greater than 0.12 ......... $F Report

 The value of Rint (i.e. _diffrn_reflns_av_R_equivalents) should normally be
 considerably less than 0.12 and in the order of magnitude of the reported
 R-values. Rint may be relatively meaningless when based on a very limited
 number of averaged data. Higher values should be accompanied by a suitable
 explanation in the _publ_section_exptl_refinement section. However,
 authors should first ensure that there are not overlooked problems
 associated with the data or the space-group. Elevated values for 
 _diffrn_reflns_av_R_equivalents may be indicative of a need to recollect 
 the data from a crystal of higher quality or that there is a problem with
 the data treatment. Consider the following:
 (a) The absorption corrections are inadequate or inappropriate.
 (b) The overall quality of the data may be poor due to the crystal quality.
 (c) The crystal is very weakly diffracting, so that a large proportion of
     essentially "unobserved" reflections are being used in the refinement.
     You should consider using a better crystal or a data collection at
     low temperature and/or, if the compound is organic, using Cu radiation.
 (d) You are working in the wrong crystal system or Laue group.
 (e) You have only a very small number of equivalent reflections, which
     may lead to artificially high values of _diffrn_reflns_av_R_equivalents 

 Note that if _diffrn_reflns_av_sigmaI/netI is also large, the quality
 of the data should be considered to be suspect. 
#=============================================================================
# >>> Check Expected number of Reflections (Max = 1 Centro, 2 - non-centro)
_021 0.01 0.05 100. 4 A   0 1 0 0   
Ratio Unique / Expected Reflections too High ... $F

 The expected number of reflections corresponds to that in the asymmetric
 unit of the Laue group. Expected ratio: less-or-equal 1 for centro symmetric
 structures and less than 2 for non-centrosymmetric structures.
 Reasons to exceed those numbers can be:
  1 - Systematic extinctions not omitted from the observed data count.
  2 - Refinement with redundant (i.e. not merged/unique) data set.
  3 - SHELXL HKLF 5 Refinement
#=============================================================================
# >>> Check Expected number of Reflections (completeness)
_022 0.05 0.10 0.15 3 A   0 1 0 0     
Ratio Unique / Expected Reflections (too) Low .. $F

 Test for data completeness. The ratio of the reported number of unique
 reflections and expected number of reflections for the resolution given is
 reported. The ratio can be low due to a missing cusp of data when collected
 with a 2D-detector. Alternatively, the wrong asymmetric part of reciprocal
 space was collected on a serial detector system.
#=============================================================================
# >>> Check Theta-Max
_023 .010 .025 0.05 3 A   0 1 0 0   
Resolution (too) Low [sin(theta)/Lambda < 0.6].. $F Degree 

 Check resolution of the data set. Alert is issued when sin(theta)/lambda < 0.6
#=============================================================================
# >>> Check for required Friedel pair averaging Z<=Si (Obsolete 1/1/2011)
_024    0    2    2 4 A   0 0 0 0 
Merging of Friedel Pairs is Indicated ..........          !

 (No longer imposed)
#=============================================================================
# >>> Check for Hmin..Lmax 
_025 .000 .000 2.00 1 A   1 0 0 0      
Hmin..Lmax Data Incomplete or Missing ..........     Please Check

 Check reported h,k,l - range with calculated range based on reported theta-max.
#=============================================================================
# >>> Check for weak data 
_026   50   60   70 3 A   0 1 0 0      
Ratio Observed / Unique Reflections too Low .... $I %    

 Check whether a sufficient fraction of the unique data is indeed above the
 2 sigma level.
#=============================================================================
# >>> Check _diffrn_reflns_theta_full
_027  .06  .07  .08 3 A   0 1 0 0     
_diffrn_reflns_theta_full (too) Low ............ $F Degree 

 Ideally (and a requirement for publication in Acta Crystallographica),
 the dataset should be essentially complete, as defined by 
 -diffrn-measured-fraction-theta-full (close to 1.0), up to 
 sin(theta)/lambda = 0.6 (i.e. 25.24 degrees MoKa).       
 The three major causes of incomplete data sets are:
 1 - A missing cusp of data due to data collection by rotation around
     the spindle axis only (standard on some image-plate systems).
     Cure: collect an additional data set after remounting the crystal.
 2 - The DENZO image processing package has problems with certain strong
     reflections. They are often excluded from the data set.
     Cure: Add an additional scan at lower power setting in order to
     include strong low order reflections.
 3 - Incomplete scans.
#=============================================================================
# >>> Check the reported _diffrn_measured_fraction_theta_max 
_028 .050 .100 0.15 3 A   0 1 0 0      
_diffrn_measured_fraction_theta_max  Low ....... $F        

 Ideally, the reported '_diffrn_measured_fraction_theta_max' value,
 corresponding to theta-max, should be close to 1.0.   
#=============================================================================
# >>> Check the reported _diffrn_measured_fraction_theta_full 
_029 .020 .040 .060 3 A   0 1 0 0     
_diffrn_measured_fraction_theta_full Low ....... $F Note   

 Ideally (and a requirement for publication in Acta Crystallographica),
 this fraction should be close to 1.0 for theta-full greater or equal
 to sin(theta/lambda) = 0.6 (i.e. 25.24 degrees for MoKa and 67.7 degrees
 for CuKa  radiation).
 The three major causes of incomplete data sets are:
 1 - A missing cusp of data due to data collection by rotation around
     the spindle axis only (standard on some image-plate systems).
     Cure: collect an additional data set after remounting the crystal.
 2 - The DENZO imageprocessing package has problems with certain strong
     reflections. They are often excluded from the data set.
     Cure: Add an additional scan at lower power setting in order to
     include strong low order reflections.
 3 - Incomplete scans, possibly based on erroneously assumed higher than
     actual symmetry.

 Note: The default value of _diffrn_measured_fraction_theta_full that
 is automatically calculated and inserted in the CIF by SHELXL-97 might
 generate A-level ALERTS when significant numbers of reflections are 
 missing at higher theta values. In order to avoid such an ALERT,
 substitute the values calculated with the SHELXL instruction 'ACTA 50'
 for _diffrn_reflns_theta_full and _diffrn_measured_fraction_theta_full
 respectively. For Mo-radiation, corresponding values of 25 degees (or
 higher) and 0.99 (or higher) are expected. (See SHELXL manual).
 PLATON may be used to analyse the case at hand (by invoking either the
 'FCF-VALIDATION' mode or the 'ASYM-VIEW' mode).
#=============================================================================
# >>> Check _diffrn_reflns_number >= reflns_number_total 
_030    0    2    2 1 A   0 0 0 0         
_diffrn_reflns_number   <   _reflns_number_total     Please Check        

 The number of measured reflections should be equal or greater than the
 number of unique reflections. 
#=============================================================================
# >>> Check need for Extinction Correction Parameter
_031  0.3  0.4  1.0 4 A   0 1 0 0
Refined Extinction Parameter within Range ...... $F Sigma

 This test checks whether a refined extinction parameter is meaningful
 i.e. whether its value is significantly larger than its corresponding s.u.
 If not, this parameter should be removed from the model and the structure
 refined without this meaningless additional parameter.
 The current default gives a warning when its value is within 3.33 s.u.
 SHELXL97-2 will not allow negative values leading to ill-convergence and
 non-zero maximum shift/error values: remove extinction parameter from the
 refinement.
#=============================================================================
# >>> Check su Flack Parameter
_032  0.2 10.0 10.0 4 A   0 0 0 0       
Std. Uncertainty on Flack Parameter Value High . $F Report

 Check the validity of the absolute structure determination.
 A high su indicates that the experimental data do not support the
 determination of the absolute structure. This will generally be the case
 with light atom MoKa data where f" is nearly zero.

 Note: Use the TWIN & BASF 0.0 instructions in SHELXL97. The default 
 FLACK parameter is not always reliable, in particular when strongly 
 correlated with the position of the origin (e.g. along y in space-group P21). 

 Please refer to Flack,H.D. & Bernardinelli, G. (1999) Acta Cryst. A55,
 908-915 and (2000) J. Appl. Cryst., 33, 1143-1148.
#=============================================================================
# >>> Check Flack Parameter value 
_033  0.3 10.0 10.0 4 A   0 0 0 0
Flack x Value Deviates > 2*sigma from Zero ..... $F Note

 Check the relevance/validity of the absolute structure determination.
 Please refer to Flack,H.D. & Bernardinelli, G. (1999) Acta Cryst. A55,
 908-915 and (2000) J. Appl. Cryst., 33, 1143-1148.

 A value of the Flack parameter that deviates significantly from zero
 (taking into account the associated s.u.) might indicate that the
 absolute structure should be inverted in case of a value closer to 1.0
 than to zero. A value close to 0.5 may be indicative of an inversion
 twin or a missed centre of inversion. 

 For valid absolute structure assignments, abs(x) should be less than
 2 * s.u., with su < 0.04. For enantiopure compounds, s.u. should be less
 than 0.1.
#=============================================================================
# >>> Check for Flack parameter value specified Z>Si, non-centro
_034    0    2    2 1 A   0 0 0 0      
No Flack Parameter Given. Z > Si, NonCentro ....     Please Do !

 No Flack parameter value given for non-centrosymmetric structure with
 heaviest atom Z > Si. This might be intentional.
#=============================================================================
# >>> Check for _chemical_absolute_configuration
_035    0    0    2 1 A   1 0 0 0             
No _chemical_absolute_configuration info given .     Please Do !

 Options are 'rm', 'ad', 'rmad', 'syn', 'unk' or '.'
                      
 rm   : absolute configuration established by the structure determination
        of a compound containing a chiral reference molecule of known
        absolute configuration.
 ad   : absolute configuration established by anomalous dispersion effects
        in diffraction measurements on the crystal.
 rmad : absolute configuration established by the structure determination
        of a compound containing a chiral reference molecule of known
        absolute configuration and confirmed by anomalous dispersion
        effects in diffraction measurements on the crystal.
 syn  : absolute configuration has not been established by anomalous
        dispersion effects in diffraction measurements on the crystal.
        The enantiomer has been assigned by reference to an unchanging
        chiral centre in the synthetic procedure.
 unk  : absolute configuration is unknown, there being no firm chemical
        evidence for its assignment to hand and it having not been 
        established by anomalous dispersion effects in diffraction 
        measurements on the crystal. An arbitrary choice of enantiomer
        has been made.
 .    : inapplicable.
#=============================================================================
# >>> Check for missing Flack Parameter su 
_036  0.5  2.0  2.0 1 A   1 0 0 0             
No s.u. Given for Flack Parameter ..............     Please Do !

 No standard uncertainty found for the Flack parameter.
 When the structure refinement was done with SHELXL97-2, the likely 
 reason for this is a missing BASF instruction. This applies in
 particular when the associated Flack parameter has the value 0.000.
 No valid conclusions on the absolute structure can be drawn in that case.
#=============================================================================
# >>> Check _diffrn_reflns_theta_full
_037    0    0    0 1 I   1 0 0 0             
_diffrn_reflns_theta_full .......... Not Given .     Please Do !

 No information is given about the theta value for which the dataset is
 complete, subject to the percentage given with the dataname 
 _diffrn_measured_fraction_theta_full. 
#=============================================================================
# >>> Check _diffrn_measured_fraction_theta_max 
_038    0    0    0 1 I   1 0 0 0              
_diffrn_measured_fraction_theta_max  Not Given .     Please Do !

 This fraction should be specified in combination with the theta value
 given with the dataname _diffrn_reflns_theta_full.
#=============================================================================
# >>> Check _diffrn_measured_fraction_theta_full 
_039    0    0    0 1 I   1 0 0 0               
_diffrn_measured_fraction_theta_full Not Given .     Please Do !

 This fraction should be specified in combination with the value for 
 _diffrn_reflns_theta_max.
#=============================================================================
# >>> Test for H-atoms [0,1]
_040  0.0 99.0 99.0 1 A   0 0 1 0  
No H-atoms in this Carbon Containing Compound ..     Please Check

 Alert for 'no H-atoms' in CIF. This is unusual for carbon containing compounds,
 but may be correct.
#=============================================================================
# >>> Test SumFormula
_041  0.0 99.0 99.0 1 A   0 0 0 1    
Calc. and Reported SumFormula    Strings  Differ     Please Check

 In the ideal case, both SumFormula strings (reported and calculated) should
 be identical. If not, the reason for the difference should be clear. Examples
 are cases where populations do not add up to integer numbers, or when solvent
 molecules have been SQUEEZED.

 Note: SHELXL97 reports population parameters in the CIF with two decimals 
 only. This may lead to non-integer atom counts in cases of disorder
 due to rounding.

 Note: Alerts _041, _042 & _045 can probably be ignored when the relevant
 values differ by the same factor.
#=============================================================================
# >>> Test MoietyFormula
_042  0.0 99.0 99.0 1 I   0 0 0 1 
Calc. and Reported MoietyFormula Strings  Differ     Please Check

 In the ideal case, the MoietyFormula string as reported should be identical
 to the MoietyFormula string calculated from the data in the CIF. If not, the
 reason should be clear. Examples are cases where there is no separating space
 between two element names or cases where populations do not add up to 
 integer numbers or when moieties are separated by '.' instead of ','.

 Example: NO3 should be given as N O3  

 Note: Alerts _041, _042 & _045 can probably be ignored when the relevant
 values differ by the same factor.
#=============================================================================
#1>>> Test for MolWeight
_043  0.1  1.0 10.0 1 A   0 0 0 1 
Calculated and Reported Mol. Weight Differ by .. $F Check

 Note: atomic weights used in the calculation of the molecular weight are
 taken from Inorg. Chim. Acta 217 (1994) 217-218 which deviate in a few cases
 slightly from the older values used in SHELXL97-2.

 Note: The tabulated atomic weights that are used may deviate from the
 actual value in case of special isotopes of e.g. Uranium or Plutonium.
#=============================================================================
#1>>> Check Reported with calculated density
_044  1.0  5.0 10.0 1 A   0 0 0 1  
Calculated and Reported Density Dx  Differ by .. $F Check 

 In the ideal case, both data items should be the same within a small 
 tolerance. If not, the reason should be clear.
#=============================================================================
#1>>> Check Reported and Calculated Z
_045  0.0  1.0  1.0 1 A   0 0 0 1 
Calculated and Reported Z Differ by ............ $F Ratio 

 In the ideal case, both data items (Z(calc) & Z(reported)) should be
 the same. If not, the reason for the difference should be clear. An example
 is the situation where PLATON gives Z = 1 when the program cannot work out
 a proper Z.

 Note: Alerts _041, _042 & _045 can probably be ignored when the relevant
 values differ by the same factor.
#=============================================================================
#1>>> Check Reported Density with calculated density from Z*MW
_046  1.0  5.0 10.0 1 A   0 0 0 1  
Reported Z, MW and D(calc) are Inconsistent .... $F

 D(calc) as calculated from the reported Z and MW is compared for consistency 
 with the reported d(calc).
#=============================================================================
#1>>> Test SumFormula Given
_047  0.0  0.0  0.0 1 A   1 0 0 0             
SumFormula Not Given ...........................     Please Do !

 The Sumformula, corresponding with the Moietyformula, should be given.
#=============================================================================
#1>>> Test MoietyFormula Given
_048  0.0 99.0 99.0 1 I   1 0 0 0
MoietyFormula Not Given ........................     Please Do ! 

 The Moiety formula (i.e. the specification of the various species in the
 structure) should be given in the CIF.

 Example: '(Cd 2+)3, (C6 N6Cr 3-)2, 2(H2 O)'
#=============================================================================
# >>> Check Calculated Density .GT. 1.0                         
_049  0.0  0.0  1.0 1 A   0 0 0 1  
Calculated Density less than 1.0 gcm-3 ......... $F Check

 The calculated density will with a few exceptions be larger than 1.0.
 A smaller value may indicate either an incomplete model or incorrect
 symmetry. (e.g. a missing 'bar' in P-1 etc.)
#=============================================================================
# >>> Test for mu given [0,1]
_050  0.0  0.0  0.0 1 A   1 0 0 0
Absorption Coefficient mu Not Given ............     Please Do !

 The linear absorption coefficient corresponding to the Sumformula should be
 given.
#=============================================================================
# >>> Test for difference mu(cif) with mu(calc) [%]
_051    1    5   10 1 A   0 0 0 1
Mu(calc) and Mu(CIF) Ratio Differs from 1.0 by . $F %      

 In the ideal case, both data items should be the same within a small
 tolerance. If not, the reason should be clear.
#=============================================================================
# >>> Test for specification absorption correction method [0,1]
_052  0.0 99.0 99.0 1 A   1 0 0 0 
Info on Absorption Correction Method Not Given .     Please Do !

 The treatment/method of absorption(correction) should be given explicitly.
 Set _exptl_absorpt_correction_type to 'none when no correction is done.
 Other recognized values are 'psi-scan', 'empirical', 'multi-scan',
 'refdelf', 'analytical', 'numerical', 'gaussian'.
#=============================================================================
# >>> Test for specification xtal_dimension_min [0,1]
_053  0.0  2.0  2.0 1 I   1 0 0 0
Minimum Crystal Dimension Missing (or Error) ...     Please Check

 The smallest crystal dimension should be supplied in the CIF.
 The expected value should be a real number (i.e. not 0.35mm)
#=============================================================================
# >>> Test for specification xtal_dimension_mid [0,1]
_054  0.0  2.0  2.0 1 I   1 0 0 0 
Medium  Crystal Dimension Missing (or Error) ...     Please Check

 The medium crystal dimension should be supplied in the CIF.
 The expected value should be a real number (i.e. not 0.35mm)
#=============================================================================
# >>> Test for specification xtal_dimension_max [0,1]
_055  0.0  2.0  2.0 1 I   1 0 0 0
Maximum Crystal Dimension Missing (or Error) ...     Please Check

 The largest crystal dimension should be supplied in the CIF.
 The expected value should be a real number (i.e. not 0.35mm)
#=============================================================================
# >>> Test for specification xtal_radius [0,1]
_056  0.0  0.0  0.0 1 I   1 0 0 0
Crystal Radius Missing for Spherical Correction      Please Do !

 Spherical correction for absorption is reported. The radius used is not
 supplied.
#=============================================================================
# >>> Test for correction for absorption needed
_057  1.1  1.2  1.3 3 A   0 1 0 0
Correction for Absorption Required   RT(exp) ... $F Do !

 You have indicated that an absorption correction has not been applied.
 (_exptl_absorpt_correction_type 'none'). However, the predicted values of
 Tmin & Tmax, based on the crystal dimensions given in the CIF, are 
 sufficiently unequal that absorption effects appear to be significant.
 Therefore, the application of a suitable absorption correction would
 appear to be required. Also check that the crystal dimensions given in the
 CIF do represent the actual crystal dimensions as closely as possible.
 Inaccuracies here can lead to a poor prediction of Tmin & Tmax and give
 rise to these alerts. It should normally be possible to estimate the 
 crystal dimensions to 2 decimal places. Rough estimates to only 1 decimal
 place may be too inaccurate to provide reliable estimates of Tmin & Tmax.
#=============================================================================
# >>> Test for specification Tmax [0,1]
_058  0.5  0.5  0.5 1 A   1 0 0 0 
Maximum Transmission Factor Missing ............          ?

 The Maximum transmission factor should be specified in the case a correction 
 for absorption was done. This is NOT the value that is calculated 
 automatically with SHELXL when a SIZE instruction is given in the SHELXL
 instruction file. The values reported by SHELXL represent the EXPECTED
 correction range. Some correction packages (e.g. SADABS) will provide
 only one 'relative- correction-factor'. In such cases, Tmax should be 
 given as Tmax-expected and Tmin = relative-correction-factor * Tmax.
#=============================================================================
# >>> Test for specification Tmin [0,1]
_059  0.5  0.5  0.5 1 A   1 0 0 0 
Minimum Transmission Factor Missing ............          ?

 The Minimum transmission factor should be specified in case a correction 
 for absorption was done. This is NOT the value that is calculated 
 automatically with SHELXL when a SIZE instruction is given in the SHELXL
 instruction file. The values reported by SHELXL represent the EXPECTED
 correction range. Some correction packages (e.g. SADABS) will provide
 only one 'relative-correction-factor'. In such cases, Tmax should be 
 given as Tmax-expected and Tmin = relative-correction-factor * Tmax.
#=============================================================================
# >>> RR Test
_060 1.10 1.50 2.00 4 I O 0 0 0 0
Ratio Tmax/Tmin (Exp-to-Rep) (too) Large ....... $F

 see IUCR WEB-Pages
#=============================================================================
# >>> RR' Test
_061 0.10 0.25 0.50 4 I O 0 0 0 0
Tmax/Tmin Range Test RR' too Large ............. $F

 see IUCR WEB-Pages
#=============================================================================
# >>> Rescale Tmin & Tmax
_062    0    2    2 4 I O 0 0 0 0
Rescale T(min) & T(max) by ..................... $F

 Some (empirical) correction packages (e.g. SADABS) will provide only one
 'relative-correction-factor'. In such cases, Tmax should be given as 
 Tmax-expected (as calculated from the crystal dimensions) and
 Tmin = relative-correction-factor * Tmax.
#=============================================================================
# >>> Test for Crystal Size
_063  0.6  0.6  5.0 4 I   0 0 0 1
Crystal Size Likely too Large for Beam Size .... $F mm

 Alert for crystals with at least one dimension probably too large for the
 homogeneous part of the X-ray beam when used for datacollection using 
 crystal monochromated radiation. An exception will be datacollection using 
 a beta-filter and a sufficiently large collimator.

 See also: C.H.Gorbitz (1999), Acta Cryst. B55, 1090-1098.
#=============================================================================
# >>> Test for T(max) .GE. T(min)
_064  0.0  0.0  0.0 1 A   0 0 0 0
Reported T(min) is Greater than Reported T(max) .         !

 Check that the values entered under _exptl_correction_T_min and
 _exptl_correction_T_max have not been reversed or if there is a 
 typographical error for one of these two items.
#=============================================================================
# >>> Test for applicability of (semi-)empirical abs.corr. [0,1]
_065  3.0  3.0  3.0 3 A O 0 0 0 0
Crystal Requires Numerical Correction mu*tmid .. $F

 For high mu * r values, numerical absorption correction procedures are
 recommended.  
#=============================================================================
# >>> Test whether Predicted and Reported Transmission Ranges are Identical
_066  0.0  2.0  2.0 1 I   0 0 0 0
Predicted and Reported Tmin&Tmax Range Identical          ? Check

 The predicted and reported transmission ranges are found to be identical
 which is not to be expected. CIF's generated with SHELXL97 report 
 transmission ranges based on the crystal dimensions supplied on the
 SIZE card. Those values have nothing to do with the actual corrections
 for absorption as applied to the data: they just report the EXPECTED range.
 Some correction packages (e.g. SADABS) will provide only one
 'relative-correction-factor'. In such cases, Tmax should be given as 
 Tmax-expected and Tmin = relative-correction-factor * Tmax.
#=============================================================================
# >>> Insure that minimum dimension less max dimension
_067  0.0  0.0  0.0 1 I   0 0 0 1
Maximum Dimension Less Min. Xtal Dimension .....     Please Check

 Minimum an Maximum dimensions are likely exchanged in the CIF.
#=============================================================================
# >>> Test for F000 Calc/Reported difference 
_068 0.01 10.0 10.0 1 I   0 0 0 1
Reported F000 Differs from Calcd (or Missing)...     Please Check

 In the ideal case, both data items should have the same value. If not, 
 the reason should be clear. A reason might be the output by SHELXL   
 of population parameters to the CIF with only two decimals. 

 Note: SHELXL counts the number of electrons in the unit cell. The result 
 will in general be an integer. This is also the number checked for here.
 The official definition calls for 'The effective number of electrons in the 
 crystal unit cell contributing to F(000)'. It may contain dispersion
 contributions and is calculated as:

 F(000) = [ (sum f~r~)^2^ + (sum f~i~)^2^ ]^1/2^

 f~r~ = real part of the scattering factors at theta = 0
 f~i~ = imaginary part of the scattering factors at theta = 0
#=============================================================================
# >>> Test for label without numerical part
_069  0.0  2.0  2.0 1 I   0 0 0 1
Atom Label without Numerical Part ..............    $A Do !

 Acta Cryst. Notes for Authors requires atom labels to contain a numerical
 part. E.g. A label of the type 'O' should be given as 'O1'.
 This is not necessarily a requirement for other journals.
#=============================================================================
# >>> Test for duplicate labels
_070  0.0  0.0  0.0 1 A   0 0 0 1
Duplicate Atomic Label on INPUT ................    $A

 The CIF contains duplicate labels posing interpretation problems for
 PLATON/CHECK. Derived geometry ALERTS may have their origin in this
 problem.
#=============================================================================
# >>> Test for uninterpretable labels
_071    0    0    0 1 A   0 0 0 1
Uninterpretable Atom Label on Input ............    $A

 The CIF contains labels posing problems for PLATON/CHECK.
 Example: label HN1 with no scattering type information supplied.
 Validation is aborted.
#=============================================================================
# >>> Test for extreme first weighting parameter (SHELXL)
_072  0.1  0.2  0.3 2 A   0 0 0 1 
SHELXL First  Parameter in WGHT Unusually Large. $F Report      

 The first parameter on the SHELXL weighting line has an exceptionally
 large value. This may indicate either improper reflection s.u.'s or
 an unresolved problem such as missed twinning.
#=============================================================================
# >>> Test for inconsistency 'constr' versus 'H-Atoms refined'
_073    0    0    0 1 I   0 0 0 1
H-atoms ref, but _hydrogen_treatment reported as    $A Check

 The structure contains refined hydrogen atoms. However the data item 
 _refine_ls_hydrogen_treatment has the value 'constr'. 
 The value 'mixed' is more appropriate.
#=============================================================================
# >>> Test for Occupancy equal 0.0
_074  0.0  1.0  1.0 1 A   0 0 0 1
Occupancy Parameter = 0.0 for ..................    $A Check

 The CIF contains an atom with occupacy less than 0.0001 
#=============================================================================
# >>> Test for Occupancy greater than 1.0
_075  0.0  0.0  0.0 1 A   0 0 0 1
Occupancy $F greater than 1.0 for ......    $A

 The CIF contains an atom with Occupancy greater than 1.0.
#=============================================================================
# >>> Test for Occupancy less than 1.0 for atom on special position
_076  0.0  1.0  1.0 1 A   0 0 0 1 
Occupancy $F less than 1.0 for Sp.pos  .    $A

 The CIF contains an atom sitting on a special position with occupancy
 specified as less than 1.0. This is often an error and the result of the
 confusion of the notions 'occupancy' and 'population parameter'. The first
 should be 1.0 for a fully occupied site. The latter multiplies the
 site-symmetry with the occupancy. Thus, for a fully occupied site on a
 mirror plane the site-symmetry will be 0.5 * 1.0 = 0.5.
 
 Note: a wrong occupancy number will lead to an incorrect expected
 chemical formula.
#=============================================================================
# >>> Test for Non-Integral # of atoms in Unit Cell                  
_077  0.0  1.0  1.0 4 A   0 0 0 1 
Unitcell contains non-integer number of atoms ..     Please Check

 The unit-cell contains a non-integer number of atoms of a given atom type.
 Valid reasons include partially occupied (solvent) sites and substitutional
 disorder.
#=============================================================================
# >>> Test for inconsistency 'geom' versus 'no H-Atoms'
_078    0    0    0 1 I   0 0 0 1
No H-atoms, but _solution_hydrogens reported as     $A Check

 The structure contains no hydrogen atoms. However the data item 
 _atom_sites_solution_hydrogen had the value 'geom'. This value is
 likely the SHELXL default and should be replaced by '.'.
#=============================================================================
# >>> Test for inconsistency 'mixed' versus 'no H-Atoms'
_079    0    0    0 1 I   0 0 0 1
No H-atoms, but _hydrogen_treatment reported as     $A Check

 The structure contains no hydrogen atoms. However the data item 
 _refine_ls_hydrogen_treatment has the value 'mixed'. This value is
 likely the SHELXL default and should be replaced by '.'.
#=============================================================================
# >>> Test maximum shift/error
_080 0.05 0.10 0.20 2 A   0 0 1 0
Maximum Shift/Error ............................ $F

 Convergence of the refinement is proved with a close to zero shift/error
 value for all refined parameters. Such a convergence is easily achieved
 with a few additional refinement cycles at little cost.
 Note: Some SHELXL-97 versions do not allow for negative Flack parameter
 values. Convergence in such a case may be never reached because the 
 Flack parameter value is reset to zero. 
#=============================================================================
# >>> Test for  maximum shift/error given
_081 0.00 0.00 0.00 1 A   0 0 0 1
No Maximum Shift/Error Given ...................     Please Do !

 A maximum shift/error should be specified in order to judge convergence.
#=============================================================================
# >>> Test for reasonable R1
_082 0.10 0.15 0.20 2 A   0 0 1 0 
High R1 Value .................................. $F Report

 A higher than usual R1 indicates either an insufficient model or poor
 quality data.
#=============================================================================
# >>> Test for extreme second weighting parameter (SHELXL)
_083  5.0 25.0 50.0 2 A   0 0 0 1
SHELXL Second Parameter in WGHT Unusually Large. $F Why ?       

 The second parameter on the SHELXL weighting line has an exceptionally
 large value. This may indicate either improper reflection s.u.'s or
 an unresolved problem such as missed twinning.
#=============================================================================
# >>> Test for reasonable wR2
_084 0.25 0.35 0.45 3 A   0 0 1 0
High wR2 Value (i.e. > 0.25) ................... $F Report

 wR2 will in general have a value twice of that of R1 with refinement on F**2.
 Significantly larger values usually indicate a poor refinement model.
 Also check for unaccounted for twinning.
#=============================================================================
# >>> Test for default SHELXL weighting scheme
_085    0   10   10 2 A   0 0 0 1
SHELXL default weighting scheme is not optimized     Please Check

 The weighting scheme is found to be left at the SHELXL default.
 This default is recommended for the preliminary structure refinement.
 It is uncommon that this unoptimized weight gives the best final refinement 
 result.
#=============================================================================
# >>> Test for reasonable S  (Too Low)
_086  0.4  0.6  0.8 2 A   0 0 0 1
Unsatisfactory S Value (Too Low or Not Given) .. $F Check

 S should in general be close to 1 at the end of a refinement with a proper
 weighting scheme. If not, there might be significant unresolved problems
 with the model.
#=============================================================================
# >>> Test for reasonable S (Too High) 
_087  2.0  4.0  6.0 2 A   0 0 0 1
Unsatisfactory S value (Too High) .............. $F Check

 S should in general be close to 1 at the end of a refinement with a proper
 weighting scheme. If not, there might be significant unresolved problems
 with the model.
#=============================================================================
# >>> Test for reasonable Data / parameter ratio  (centro)
_088 10.0 12.5 16.7 3 A   0 0 1 0
Poor Data / Parameter Ratio .................... $F Note

 The data/parameter ratio should in general be higher than 10 for a quality
 structure determination. This ratio can be improved by not refining 
 C-H parameters other than riding on their carrier atom.
#=============================================================================
# >>> Test for reasonable Data / parameter ratio (non-centro) (Zmax < 18)
_089 13.5 18.0 25.0 3 A   0 0 1 0 
Poor Data / Parameter Ratio (Zmax < 18) ........ $F Note

 The data/parameter ratio should in general be higher than 7 for a quality
 determination of a structure containing atoms with Z less than 18.
 This ratio can be improved by not refining C-H parameters other than riding
 on their carrier atom.
 
 Note: The number of reflections used in this ratio is the number obtained 
 by Laue group averaging.
#=============================================================================
# >>> Test for reasonable Data / parameter ratio (non-centro) (ZMAX > 18)
_090 10.0 16.5 25.0 3 A   0 0 1 0
Poor Data / Parameter Ratio (Zmax > 18) ........ $F Note

 The data/parameter ratio should in general be higher than 10 for a quality
 determination for a structure containing heavy atoms with ZMAX greater
 than 17. This ratio can be improved by not refining C-H parameters other
 than riding on their carrier atom.
#=============================================================================
# >>> Test for 'No-wavelength given' 
_091    0    0    0 1 A   1 0 0 0
No Wavelength found in CIF - 0.71073 Ang Assumed     Please Check

 No Wavelength specification found in the CIF.
#=============================================================================
# >>> Test for wavelength type [Cu,Mo,Ag]          
_092    0    0    0 4 A   0 0 0 1
Check: Wavelength given is not Cu,Ga,Mo,Ag Ka .. $F Ang.        

 Warning: specified wavelength is not Cu,Mo or Ag Ka radiation.
 Valid exceptions are Neutron and Synchrotron data.
#=============================================================================
# >>> Test for inconsistency 'mixed' versus 'no refined H positions'
_093    0    0    0 1 I   0 0 0 1
No su's on H-positions, refinement reported as .    $A

 The 'mixed' type Hydrogen atom refinement is reported (SHELXL-97 default).
 However, no Hydrogen atoms with freely refined positions are found in the
 CIF. Likely, the value 'constr' or 'refU' for 
 '_refine_ls_hydrogen_treatment' will be more appropriate (e.g. when all
 Hydrogen atoms have been refined in the riding mode on their carrier atom). 
#=============================================================================
# >>> Test for maximum/minimum residual density ratio
_094  2.0  4.0  8.0 2 A   0 0 1 0
Ratio of Maximum / Minimum Residual Density .... $F Report  

 The ratio of the maximum and minimum residual density excursions is 
 unusual. This might indicate unaccounted for twinning or missing atoms
 (e.g. associated with disordered solvent).
#=============================================================================
# >>> Test for residual density maximum given [0,1]
_095    0    0    0 1 A   1 0 0 0
No Residual Density Maximum Given ..............     Please Do !

 No residual electron density maximum given in CIF.
#=============================================================================
# >>> Test for residual density minimum given [0,1]
_096    0    0    0 1 A   1 0 0 0
No Residual Density Minimum Given ..............     Please Do !

 No residual electron density minimum given in CIF.
#=============================================================================
# >>> Test maximum residual density (Reported) 
_097 0.75  1.0  2.0 2 A   0 0 1 0
Large Reported Max.  (Positive) Residual Density $F eA-3

 Residual density maximum larger than expected. This might be caused by
 residual absorption artefacts, unaccounted for twinning, wrongly assigned 
 atom types and other model errors. 
#=============================================================================
# >>> Test for minimum residual density (Reported)
_098 0.75  1.0  2.0 2 A   0 0 1 0
Large Reported Min.  (Negative) Residual Density $F eA-3

 Residual density minimum larger than expected. This might be caused by
 residual absorption artefacts, wrongly assigned atom types and other
 model errors.
#=============================================================================
# >>> Test for minimum residual density less zero [0, 1]
_099  0.0  0.0  0.0 1 A   0 0 0 1
Minimum (Negative) Residual Density .GE. 0 !!... $F eA-3

 Likely interchanged maximum and minimum values.

 Alternatively, the minimum residual density has the (unlikely) value 
 zero.
#=============================================================================
# >>> Test for insufficient digits for special pos 1/3 & 2/3 in x-coord.        
_101    0    0   10 2 A   1 0 0 0
Limited Precision x-coordinate  $A Suspect:      $B Do !

 Fractions of the type 1/3 and 2/3 for the positional parameters of
 atoms in special positions should be provided with sufficient digits.
 (i.e. 0.66667 and 0.33333).
#=============================================================================
# >>> Test for insufficient digits for special pos 1/3 & 2/3 in x-coord.        
_102    0    0   10 2 A   1 0 0 0
Limited Precision y-coordinate  $A Suspect:      $B Do !

 Fractions of the type 1/3 and 2/3 for the positional parameters of
 atoms in special positions should be provided with sufficient digits.
 (i.e. 0.66667 and 0.33333).
#=============================================================================
# >>> Test for insufficient digits for special pos 1/3 & 2/3 in x-coord.        
_103    0    0   10 2 A   1 0 0 0
Limited Precision z-coordinate  $A Suspect:      $B Do !

 Fractions of the type 1/3 and 2/3 for the positional parameters of
 atoms in special positions should be provided with sufficient digits.
 (i.e. 0.66667 and 0.33333).
#=============================================================================
# >>> Test for additional translational symmetry [0, 1] 
_104    0    0    0 1 A   0 0 0 1
The Reported Crystal System is Inconsistent with    $A Check 

 Check the reported crystal system against the reported space group.
 Alternatively, no crystal system was reported.
#=============================================================================
# >>> Test for additional translational symmetry [0, 1] 
_110  0.5  0.5  999 2 A   0 0 0 1 
ADDSYM Detects Potential Lattice Centering .....          ? Check

 Tests for missed symmetry are done with ADDSYM, an expanded MISSYM (C)
 clone. These tests warn for missed or possible higher (pseudo) symmetry in
 the structural model (i.e. based on the coordinate data).
 Close examination of the situation at hand is indicated in order to
 prove/disprove the issue (usually in combination with the reflection data).
 Report on potential (pseudo/real) lattice centering or cell halving.
 Note: H-atoms and disordered atoms are not taken into account in the tests.
#=============================================================================
# >>> Test for additional centre of symmetry [0, 100] 
_111   90   95  100 2 A   0 0 0 1
ADDSYM Detects (Pseudo) Centre of Symmetry ..... $I %Fit  

 Tests for missed symmetry are done with ADDSYM, an expanded MISSYM (C)
 clone. These tests warn for missed or possible higher (pseudo) symmetry in
 the structural model (i.e. based on the coordinate data). Close examination
 of the situation at hand is indicated in order to prove/disprove the issue
 (usually in combination with the reflection data).
 This ALERT reports on a potential additional (pseudo/real) inversion centre.
 A pseudo-centre may be incompatible with existing symmetry elements.
 Chiral molecules are incompatible with an inversion centre.
 Note: H-atoms and disordered atoms are not taken into account in the test.
#=============================================================================
# >>> Test for additional symmetry [0, 1] 
_112   50   50  100 2 A   0 0 0 1
ADDSYM Detects Additional (Pseudo) Symm. Elem...    $A Check

 Tests for missed symmetry are done with ADDSYM, an expanded MISSYM (C)
 clone. These tests warn for missed or possible higher (pseudo) symmetry in
 the structural model (i.e. based on the coordinate data). Close examination
 of the situation at hand is indicated in order to prove/disprove the issue 
 (usually in combination with the reflection data).
 This ALERT reports on potential additional (pseudo/real) rotation axes and
 mirrors.
 
 In addition, (pseudo/real) lattice centering/translations are reported as 
 A, B, C, I, X, Y, Z, S. (Here S stands for special and not covered by the
 preceding types). Full details on the situation at hand should be gleaned
 from an actual PLATON/ADDSYM run.

 Chiral molecules are incompatible with an inversion centre or (glide)planes.
 Note: H-atoms and disordered atoms are not taken into account in the tests.
#=============================================================================
# >>> Report New space-group suggested by ADDSYM    
_113   90   95   99 2 A   0 0 0 1
ADDSYM Suggests Possible Pseudo/New Space group.    $A Check

 Tests for missed symmetry are done with ADDSYM, an extended MISSYM (C)
 clone. These tests warn for missed or possible higher (pseudo) symmetry in
 the structural model (i.e. based on the coordinate data). Close examination
 of the situation at hand is indicated in order to prove/disprove the issue
 (usually in combination with the reflection data). 
 Chiral molecules are incompatible with an inversion centre or (glide)planes.
 For an example of reported pseudo-symmetry see I.A.Guzei et al, (2002).
 Acta Cryst. C58, m141-m143.

 Note: H-atoms and disordered atoms (i.e. atoms with population less
 than 1.0) are not taken into account in the tests. This may artificially
 lead to a symmetry higher than the actual one.

 Note: Atoms are treated as having the same atom type in order to catch
 certain types of disorder or incorrect atom type assignment.
#=============================================================================
# >>> Report on ADDSYM problem                     
_114    0    2    2 2 A   0 0 0 1
ADDSYM Could not (Re)Construct Proper Spacegroup     Please Check 

 ADDSYM has problems to reconstruct a space group from the symmetry 
 operation found in the symmetry expanded coordinate set. The reason being
 either intricate additionally detected pseudo-symmetry or serious errors
 in the data set.
#=============================================================================
# >>> Test for non-crystallographic centre of symmetry [0, 100] 
_115   50  100  100 5 A   0 0 0 1
ADDSYM Detects Noncrystallographic Inversion ... $I %       

 Tests for missed symmetry are done with ADDSYM, an expanded MISSYM (C)
 clone. This ALERT reports on local inversion symmetry, not compatible
 with the reported space-group symmetry.

 Note: H-atoms and disordered atoms are not taken into account in the test.
#=============================================================================
# >>> Report Problem with symmetry operator syntax                
_119    0    0    0 1 A   0 0 0 1
Problem with the Syntax of a Symmetry Operation. $A Check  

 A symmetry operation should be specified in the CIF either without
 spaces or between quotes.
#=============================================================================
# >>> Test for consistent _symmetry_space_group_name_H-M and Symm Opp
_120    0   10   10 1 A   0 0 0 1
Reported SPGR $A Inconsistent with Explicit      $B Check

 Space group symmetry should be provided in the CIF both explicitly with a
 _symmetry_equiv_pos_as_xyz loop and implicitly with
 _symmetry_space_group_name-H-M.

 An unusual (non-standard) choice of origin may also raise this ALERT.
 Please check and Explain.
#=============================================================================
# >>> Test for valid _symmetry_space_group_name_H-M
_121    0   10   10 1 A   1 0 0 0
Invalid _symmetry_space_group_name_H-M .........       $A Check

 Symmetry in the CIF should be provided both explicitly with a
 _symmetry_equiv_pos_as_xyz loop and implicitly with
 _symmetry_space_group_name_H-M.
 Test for valid _symmetry_space_group_name_H-M symbol.
#=============================================================================
# >>> Test for ? _symmetry_space_group_name_H-M
_122    0    0    0 1 A   1 0 0 0
No _symmetry_space_group_name_H-M Given ........     Please Do !

 Symmetry in the CIF should be provided both explicitly with a
 _symmetry_equiv_pos_as_xyz loop and implicitly with
 _symmetry_space_group_name_H-M.
 Test for missing (i.e. ?) _symmetry_space_group_name_H-M symbol.
#=============================================================================
# >>> Test for Interpretable Space Group Symmetry
_123    0    0    0 1 A   1 0 0 0
Uninterpretable or Inconsistent Space Group Info.    Please Check

 Symmetry in the CIF should be provided in the CIF both explicitly with a
 _symmetry_equiv_pos_as_xyz loop and implicitly with
 _symmetry_space_group_name_H-M or _symmetry_space_group_name_H-M_alt.
 Test for uninterpretable or inconsistent Space group information.
#=============================================================================
# >>> Test for _symmetry_equiv_pos_as_xyz present 
_124    0    0    0 1 A   1 0 0 0
Uninterpretable or Absent '_symmetry_equiv_pos_as_xyz'    ? Check 

 Symmetry in the CIF should be provided in the CIF both explicitly with a
 _symmetry_equiv_pos_as_xyz loop and implicitly with
 _symmetry_space_group_name_H-M.
 Test for uninterpretable or absent explicit symmetry records
#=============================================================================
# >>> Test for ? _symmetry_space_group_name_Hall
_125    0   10   10 4 I   1 0 0 0
No '_symmetry_space_group_name_Hall' Given .....     Please Do !

 Optionally specify the Hall symbol. The Hall symbol provides an
 unambiguous definition of the space-group symmetry where the Hermann-
 Mauguin symbol leaves room for alternative choices of the origin.
 E.g. for space-group P21, the screw axis is in general taken to coincide 
 with the b-axis. However, sometimes it is chosen to be shifted by 1/4
 in the c-axis direction to bring out the relation with P21/c. The Hall
 symbols will be 'P 2yb' and 'P 2ybc' respectively. 

 Refer to: S.R.Hall, Space Group Notation with an Explicit Origin;
           Acta Cryst. (1981), A37, 517-525.

       or: http://www.kristall.ethz.ch/LFK/software/sginfo/hall_symbols.html
#=============================================================================
# >>> Test for  _symmetry_space_group_name_Hall error
_126    0   10   10 1 A   0 0 0 1
Error in or Uninterpretable Hall Symbol  .......    $A$B Check

 The reported Hall-symbol is found to be in error or uninterpretable. 

 Refer to: S.R.Hall, Space Group Notation with an Explicit Origin;
           Acta Cryst. (1981), A37, 517-525.

       or: http://www.kristall.ethz.ch/LFK/software/sginfo/hall_symbols.html
#=============================================================================
# >>> Test for  _symmetry_space_group_name_Hall consistency 
_127    0   10   10 1 A   0 0 0 1
Implicit Hall Symbol  Inconsistent with Explicit    $A$B Check

 The reported Hall-symbol is found to be inconsistent with the one derived
 from the explicit symmetry operations.

 Alternatively, no Hall-symbol could be derived by PLATON for the explicit 
 set of symmetry operations. This may be the case when an unusual origin
 is chosen.

 Refer to: S.R.Hall, Space Group Notation with an Explicit Origin;
           Acta Cryst. (1981), A37, 517-525.

       or: http://www.kristall.ethz.ch/LFK/software/sginfo/hall_symbols.html
#=============================================================================
# >>> Test for non-standard space_group settings
_128    0   10   10 4 A   0 0 0 1
Alternate Setting for Input Space Group  $A    $B Note

 P21/n and I2/a etc. settings are often preferred over P21/c and C2/c when 
 that leads to a closer to 90 degrees beta angle.
#=============================================================================
# >>> Test for unusual non-standard Space group name        
_129    0    0    0 4 A   0 0 0 1
Unusual Space group Specified ..................    $A Check 

 The reported space-group name is unusual. 
#=============================================================================
# >>> Test for Cubic: a = b = c
_130    0    0    0 1 A   0 1 0 0
Cubic : a, b & c Dimensions Differ ...........       Please Check

 Symmetry constraints on cell dimensions are checked.
#=============================================================================
# >>> Test for Cubic: alpha = beta = gamma = 90
_131    0    0    0 1 A   0 1 0 0
Cubic : alpha, beta and gamma should be 90 Deg Exact Please Check

 Symmetry constraints on cell dimensions are checked.
#=============================================================================
# >>> Test for Trigonal/Hexagonal : a = b
_132    0    0    0 1 A   0 1 0 0
Trigonal/Hexagonal a and b Differ ..............     Please Check

 Symmetry constraints on cell dimensions are checked.
#=============================================================================
# >>> Test for Trigonal/Hexagonal : alpha = beta = 90 
_133    0    0    0 1 A   0 1 0 0
Trigonal/Hexagonal alpha and beta should be 90 Deg   Please Check

 Symmetry constraints on cell dimensions are checked.
#=============================================================================
# >>> Test for Trigonal/Hexagonal : gamma = 120  
_134    0    0    0 1 A   0 1 0 0 
Trigonal/Hexagonal gamma should be 120 Deg Exact     Please Check

 Symmetry constraints on cell dimensions are checked.
#=============================================================================
# >>> Test for Tetragonal: a = b
_135    0    0    0 1 A   0 1 0 0
Tetragonal: a and b should be Equal ...........      Please Check

 Symmetry constraints on cell dimensions are checked.
#=============================================================================
# >>> Test for Tetragonal: alpha = beta = gamma = 90
_136    0    0    0 1 A   0 1 0 0
Tetragonal: alpha, beta & gamma should be 90 Deg     Please Check

 Symmetry constraints on cell dimensions are checked.
#=============================================================================
# >>> Test for Orthorhombic: alpha = beta = gamma = 90
_137    0    0    0 1 A   0 1 0 0
Orthorhombic: alpha, beta & gamma should be 90 Deg   Please Check

 Symmetry constraints on cell dimensions are checked.
#=============================================================================
# >>> Test for Monoclinic more than 1 angle off 90 degrees 
_138    0    0    0 1 A   0 1 0 0
Monoclinic: More than one Angle Unequal 90.0 ...     Please Check

 Symmetry constraints on cell dimensions are checked.
#=============================================================================
# >>> Test for Rhombohedral a = b = c                      
_139    0    0    0 1 A   0 1 0 0
Rhombohedral: a, b & c are not all Exactly Equal     Please Check            

 Symmetry constraints on cell dimensions are checked.
#=============================================================================
# >>> Test for Rhombohedral alpha = beta = gamma 
_140    0    0    0 1 A   0 0 0 0
Rhombohedral: alpha, beta & gamma are Not All Equal  Please Check

 Symmetry constraints on cell dimensions are checked.
#=============================================================================
#1>>> su on a - axis small or missing
_141    0   10   10 4 A   1 0 0 0
su on a - Axis Small or Missing ................ $F Ang.

 The su on the a-axis is small or missing. The presence of su's (where
 required) and value are checked. Su's as given by the diffractometer
 software are often much smaller then realistic.
#=============================================================================
#1>>> su on b - axis small or missing
_142    0   10   10 4 A   1 0 0 0
su on b - Axis Small or Missing ................ $F Ang.

 The su on the b-axis is small or missing. The presence of su's (where
 required) and value are checked. Su's as given by the diffractometer 
 software are often much smaller then realistic.
#=============================================================================
#1>>> su on c - axis small or missing
_143    0   10   10 4 A   1 0 0 0
su on c - Axis Small or Missing ................ $F Ang.

 The su on the c-axis is small or missing. The presence of su's (where
 required) and value are checked. Su's as given by the diffractometer
 software are often much smaller then realistic.
#=============================================================================
#1>>> su on alpha small or missing
_144    0   10   10 4 A   1 0 0 0
su on alpha    Small or Missing ................ $F Degree

 The su on alpha is small or missing. The presence of su's (where required)
 and value are checked. Su's as given by the diffractometer software are
 often much smaller then realistic.
#=============================================================================
#1>>> su on beta  small or missing
_145    0   10   10 4 A   1 0 0 0
su on beta     Small or Missing ................ $F Degree

 The su on beta is small or missing. The presence of su's (where required)
 and value are checked. Su's as given by the diffractometer software are
 often much smaller then realistic.
#=============================================================================
#1>>> su on gamma small or missing
_146    0   10   10 4 A   1 0 0 0
su on gamma    Small or Missing ................ $F Degree

 The su on gamma is small or missing. The presence of su's (where required)
 and value are checked. Su's as given by the diffractometer software are
 often much smaller then realistic.
#=============================================================================
#1>>> su on symmetry restricted cell angle
_147    0   10   10 1 A   0 1 0 0
su on Symmetry Constrained Cell Angle(s) .......     Please Check 

 There should be no s.u. on symmetry constrained cell angles.
 Example: No su on alpha, beta and gamma for orthorhombic symmetry.
#=============================================================================
#1>>> su on a,b, or c - axis too large 
_148    0   10   10 3 A   0 1 0 0
su on the $A - Axis is (Too) Large ........ $F Ang.

 The su on the reported -axis is unexpectedly large. 
#=============================================================================
#1>>> su on alpha, beta or gamma too large 
_149 0.10 0.20   10 3 A   0 1 0 0 
su on the $A  Angle is Too Large .......... $F Degree

 The su on the reported angle is too large.
#=============================================================================
#1>>> Check Volume
_150 0.5   1.0  1.0 1 A   1 0 0 0
Volume as Calculated Differs from that Given ... $F Ang-3

 An ALERT is issued when the reported unit cell volume differs significantly 
 from the volume calculated on the basis of the supplied cell dimensions.
#=============================================================================
# >>> Check for s.u. on Volume
_151    0   10   10 1 A   1 0 0 0
No su (esd) Given on Volume ....................     Please Do !

 Missing s.u. on cell volume.
#=============================================================================
# >>> Check for consistency of su on Volume and cell parameters
_152    1   99   99 1 I   0 0 0 0 
The Supplied and Calc. Volume s.u. Differ by ... $I Units  

 Some software packages calculate Volume su's incorrectly. The correct formula
 for triclinic, monoclinic and orthorhombic systems
 (based on the propagation of error expression) may be found in:

 M. Nardelli, Computer & Chemistry, (1983), 7, 95-98.

 or

 C. Giacovazzo ed. in 'Fundamentals of Crystallography', Second Edition,
 Oxford University Press, 2003,  p135.

 Also note that several cell parameters for higher symmetry cells are no
 longer independent. S.u. calculations need special treatment in those cases.
#=============================================================================
# >>> test for equal axial su's       
_153    0   10   10 1 I   0 0 0 1
The su's on the Cell Axes   are Equal .......... $F Ang.

 The reported cell axes su's are reported equal. Please check whether
 this is correct or a software default value.
#=============================================================================
# >>> test for equal cell angle su's
_154    0   10   10 1 I   0 0 0 1
The su's on the Cell Angles are Equal .......... $F Degree

 The reported cell angle su's are reported equal. Please check whether
 this is correct or a software default value.
#=============================================================================
# >>> Check for reduced cell aP 
_155    0   10   10 4 A   0 0 0 1
The Triclinic Unitcell is NOT Reduced ..........     Please Do ! 

 Unless for special reasons related to the structure/content, a unit-cell and
 structure is best reported with reference to the Niggli Reduced Cell.
 This ALERT may originate also from a failure to order the axes from
 small to large.
#=============================================================================
# >>> Check for non-standard axial order
_156    0   10   10 4 A   0 0 0 1
Axial System Input Cell not Standard ...........     Please Do ! 

 The axial order should be from small to large in the triclinic cell.
#=============================================================================
# >>> Check for non-standard monoclinic beta angle less 90 Degrees. 
_157  0.0  10.  10. 4 A   0 0 0 1
Non-standard Monoclinic Beta Angle less 90 Deg   $F Degree

 By convention, the Monoclinic beta angle is always chosen to be larger than
 90.0 Degrees. A trivial transformation (1 0 0/0 -1 0/0 0 -1) should be
 applied to the data.
#=============================================================================
# >>> Check for standard reduced cell  
_158    0   10   10 4 A   0 0 0 1
The Input Unitcell is NOT Standard/Reduced .....     Please Check

 Unless for special reasons related to the structure/content, a unit-cell and
 structure is best reported with reference to the Niggli Reduced Cell.
#=============================================================================
# >>> Missing x-coordinate su
_161    0   10   10 4 A   0 0 0 1
Missing or Zero su (esd) on x-coordinate for ...    $A

 Missing or Zero su (esd) on x-coordinate.

 Positional parameters for all non-hydrogen atoms in general positions are
 checked for the presence of a non-zero s.u. on them. This includes
 parameters fixed to fix the origin in polar space-groups which is no longer
 necessary when refinement is done with modern programs (e.g. SHELXL, XTAL).
#=============================================================================
# >>> Missing y-coordinate su
_162    0   10   10 4 A   0 0 0 1
Missing or Zero su (esd) on y-coordinate for ...    $A

 Missing or Zero su (esd) on y-coordinate.

 Positional parameters for all non-hydrogen atoms in general positions are
 checked for the presence of a non-zero s.u. on them. This includes
 parameters fixed to fix the origin in polar space-groups (e.g. P21) which 
 is no longer necessary when refinement is done with modern programs
 (e.g. SHELXL, XTAL).
#=============================================================================
# >>> Missing z-coordinate su
_163    0   10   10 4 A   0 0 0 1
Missing or Zero su (esd) on z-coordinate for ...    $A

 Missing or Zero su (esd) on z-coordinate.

 Positional parameters for all non-hydrogen atoms in general positions are
 checked for the presence of a non-zero s.u. on them. This includes
 parameters fixed to fix the origin in polar space-groups (e.g. P41) which 
 is no longer necessary when refinement is done with modern programs 
 (e.g. SHELXL, XTAL).
#=============================================================================
# >>> Check for Refined C-H H-Atoms
_164    0   10   10 4 A   0 0 1 0
Nr. of Refined C-H H-Atoms in Heavy-Atom Struct. $I Note

 Warning: Refined C-H H-atoms in heavy-atom structure (i.e. containing an
 element beyond element #18). Such H-atoms are in general better refined
 at calculated positions riding on the atoms they are attached to. A
 better data over parameter ratio will be achieved.
#=============================================================================
# >>> Check for R-flagged Non-H Atoms
_165    0   10   10 3 A   0 0 0 1
Nr. of Status R Flagged Non-Hydrogen Atoms ..... $I

 Report on restrained (riding) Non-Hydrogen atoms. Note: This may lead to
 non meaningfull bond and angle su's (ALERTS _751, _752). 
 R-flagged atoms may arise unintentional being caused by an "AFIX 0" line 
 being missing in a shelxl.ins file (SHELXL-97 refinement).
 Alternatively, the number of refined parameters may have been limited
 deliberately (e.g. by refinement of C-F with fixed known geometry,
 similar to C-H) in order to keep the data/parameter ratio acceptable. 
#=============================================================================
# >>> Check for calc flagged atoms with s.u.s on coordinates
_166    0   10   10 4 A   0 0 0 1
S.U's Given on Coordinates for calc-flagged ....    $A

 Calc-flagged atoms are not supposed to carry s.u.'s on their coordinates.
#=============================================================================
# >>> Check for AFIX 1 Record(s) in CIF-Embedded shelxl.res                  
_169    0    0    0 4 A   0 0 0 1
The CIF-Embedded .res File Contains AFIX 1 Recds $I Report

 The use of 'AFIX 1' record(s) in the SHELXL .res file should be documented in
 the experimental section of the associated publication.
#=============================================================================
# >>> Check for sufficient data in in Atom data loop         
_170    0    0    0 4 A   0 0 0 1
Insufficient Data in Coordinate loop ...........    $A

 Insufficient data encountered in coordinate loop.
 A possible cause might be the use of a SHELX style '=' continuation line. 
#=============================================================================
# >>> Check for EADP Record(s) in CIF-Embedded shelxl.res                  
_171    0    0    0 4 A   0 0 0 1
The CIF-Embedded .res File Contains EADP Records $I Report

 The use of EADP record(s) in the SHELXL .res file should be documented in the
 experimental section of the associated publication.
#=============================================================================
# >>> Check for DFIX Record(s) in CIF-Embedded shelxl.res                     
_172    0    0    0 4 A   0 0 0 1
The CIF-Embedded .res File Contains DFIX Records $I Report

 The use of DFIX record(s) should be documented in the experimental section
 of the associated publication.
#=============================================================================
# >>> Check for DANG Record(s) in CIF-Embedded shelxl.res      
_173    0    0    0 4 A   0 0 0 1
The CIF-Embedded .res File Contains DANG Records $I Report

 The use of DANG record(s) should be documented in the experimental section
 of the associated publication.
#=============================================================================
# >>> Check for FLAT Record(s) in CIF-Embedded shelxl.res      
_174    0    0    0 4 A   0 0 0 1
The CIF-Embedded .res File Contains FLAT Records $I Report

 The use of FLAT record(s) should be documented in the experimental section
 of the associated publication.
#=============================================================================
# >>> Check for SAME Record(s) in CIF-Embedded shelxl.res      
_175    0    0    0 4 A   0 0 0 1
The CIF-Embedded .res File Contains SAME Records $I Report

 The use of SAME record(s) n the SHELXL .res file should be documented in the
 experimental section of the associated publication.
#=============================================================================
# >>> Check for SADI Record(s) in CIF-Embedded shelxl.res      
_176    0    0    0 4 A   0 0 0 1
The CIF-Embedded .res File Contains SADI Records $I Report

 The use of SADI record(s) in the SHELXL .res file should be documented in the
 experimental section of the associated publication.
#=============================================================================
# >>> Check for DELU Record(s) in CIF-Embedded shelxl.res      
_177    0    0    0 4 A   0 0 0 1
The CIF-Embedded .res File Contains DELU Records $I Report

 The use of DELU record(s) in the SHELXL .res file should be documented in the
 experimental section of the associated publication.
#=============================================================================
# >>> Check for SIMU Record(s) in CIF-Embedded shelxl.res      
_178    0    0    0 4 A   0 0 0 1
The CIF-Embedded .res File Contains SIMU Records $I Report

 The use of SIMU record(s) in the SHELXL .res file should be documented in the
 experimental section of the associated publication.
#=============================================================================
# >>> Check for CHIV Record(s) in CIF-Embedded shelxl.res      
_179    0    0    0 4 A   0 0 0 1
The CIF-Embedded .res File Contains CHIV Records $I Report

 The use of CHIV record(s) in the SHELXL .res file should be documented in the
 experimental section of the associated publication.
#=============================================================================
# >>> Check Rounding of Cell Axes and Angles                           
_180    0    0    0 4 I   0 1 0 0
Check Cell Rounding: # of Values Ending with 0 = $I

 It is unusual that more cell parameters end with a zero and the su is 10.
 This problem might be caused by the specification of insufficient 
 'meaningful' digits as compared to the reported su. 
 
 see also: W.Clegg, Acta Cryst. (2003) E59, e2-e5.
#=============================================================================
# >>> Check for all angles exactly 90 degrees in monoclinic
_181    0    0    2 1 A   1 0 0 0
All Angles Exactly 90 Degrees in Monoclinic Cell     Please Check

 One of the angles in a monoclinic cell is expected to be not exactly 90
 degrees.  
#=============================================================================
# >>> Check for at least one s.u. greater than zero in monoclinic
_182    0    0    2 1 A   1 0 0 0
All Angles with zero s.u. in Monoclinic Cell ...     Please Check

 One angle should have an s.u. greater than zero in a monoclinic cell.
#=============================================================================
# >>> Test for consistency of cell & diffraction temperatures       
_193    0    5   10 1 I   0 1 0 0
Cell and Diffraction Temperatures differ by .... $I Degree

 The reported _cell_measurement_temperature deviates from the reported 
 _diffrn_ambient_temperature values.
#=============================================================================
# >>> Check for missing _cell_measurement_reflns_used datum         
_194    0   10   10 1 I   1 0 0 0
Missing _cell_measurement_reflns_used datum ....     Please Do !  

 Please supply value for _cell_measurement_reflns_used
#=============================================================================
# >>> Check for missing _cell_measurement_theta_max datum               
_195    0   10   10 1 I   1 0 0 0
Missing _cell_measurement_theta_max   datum ....     Please Do ! 

 Please supply value for _cell_measurement_theta_max  
#=============================================================================
# >>> Check for missing _cell_measurement_theta_min datum          
_196    0   10   10 1 I   1 0 0 0 
Missing _cell_measurement_theta_min   datum ....     Please Do !  

 Please supply value for _cell_measurement_theta_min
#=============================================================================
# >>> Test for specification of unitcell measurement temperature       
_197    0    0    0 1 I   1 0 0 0 
Missing            _cell_measurement_temperature     Please Supply

 Please specify the temperature (Kelvin) at which the unit-cell was
 determined.
#=============================================================================
# >>> Test for specification of Datacollection temperature
_198    0    0    0 1 A   1 0 0 0
Missing              _diffrn_ambient_temperature     Please Supply

 Please specify the temperature (Kelvin) at which the intensity data were 
 collected.
#=============================================================================
# >>> Test for SHELXL Roomtemperature Default   (Cell)       
_199    0    0    0 1 I   0 0 0 1
Reported _cell_measurement_temperature ..... (K) $I Check

 The cell determination temperature is set in the CIF by default by SHELXL to
 293 K if the TEMP instruction is not used. The actual temperature is likely 
 either slightly or significantly (for a low temperature data collection)
 different.
#=============================================================================
# >>> Test for SHELXL Roomtemperature Default (Datacollection)
_200    0    0    0 1 I   0 0 0 1
Reported   _diffrn_ambient_temperature ..... (K) $I Check

 The data collection temperature is set in the CIF by default by SHELXL to
 293 K if the TEMP instruction is not used. The actual temperature is likely
 either slightly or significantly (for a low temperature data collection) 
 different.

#=============================================================================
# >>> Test for isotropic non-H atoms in main residue(s)
_201    0    0   10 2 A   0 0 1 0
Isotropic non-H Atoms in Main Residue(s) ....... $I Report

 This test reports on non-hydrogen atoms that were refined with isotropic
 displacement parameters only in the main residue. Such a practice is unusual
 by modern standards and only needed for minor disorder modelling.
#=============================================================================
# >>> Test for isotropic non-H atoms in anion ? or solvent ? 
_202    0   50   50 3 A   0 0 1 0 
Isotropic non-H Atoms in Anion/Solvent ......... $I

 This test reports on isotropically refined atoms in small moieties (usually
 anions or solvent).
#=============================================================================
# >>> Test for negative non-Hydrogen U(iso)
_203    0    0    0 2 A   0 0 1 0
Negative Isotropic ADP for $A ............. $F Report

 Isotropic U(iso) values are expected to have a positive value. 
#=============================================================================
# >>> Test for 'all-isotropic adp(s) 
_210    0    0   10 3 A   0 0 1 0
No Anisotropic ADP's Found in CIF ..............     Please Check

 No anisotropically refined atoms in CIF ?
#=============================================================================
# >>> Test for NPD ADP's  (1.0) in main residue(s)
_211    0    0  0.5 2 A   0 0 1 0
ADP of Atom $A is N.P.D. or (nearly) 2D ...     Please Check

 This test reports on non-positive definite (i.e. complex and unrealistic) 
 anisotropic displacement parameters in the main residue.
#=============================================================================
# >>> Test for NPD ADP's in anion? & solvent ? [0, 1]
_212    0  0.5   99 2 A   0 0 1 0
ADP of Atom $A is N.P.D. or (nearly) 2D ...     Please Check 

 This test reports on non-positive definite (i.e. complex and
 unrealistic) anisotropic displacement parameters in an anion or solvent
 residue.
#=============================================================================
# >>> Test ratio adp max/min in main residue(s)
_213  3.0  4.0  5.0 2 A   0 0 1 0
Atom $A         has ADP max/min Ratio ..... $F $B 

 The main axes values of the ADP(S) of the main residue(s) are determined and
 ordered: U1 < U2 < U3. The value of SQRT(U3/U1) main axis ADP ratio (Angstrom
 Units) is tested for the main residue(s). Large values may indicate unresolved
 disorder. Oblate criterium: U3 - U2 < U2 - U1. Prolate otherwise.
#=============================================================================
# >>> Test ratio adp max/min in anion ? or solvent ?
_214  4.0  5.0  6.0 2 A   0 0 1 0
Atom $A (Anion/Solvent) ADP max/min Ratio   $F $B

 The main axes values of the ADP(S) of the minor residue(s) are determined and
 ordered: U1 < U2 < U3. The value of SQRT(U3/U1) main axis ADP ratio (Angstrom
 Units) is tested for the main residue(s). Large values may indicate unresolved
 disorder. Oblate criterium: U3 - U2 < U2 - U1. Prolate otherwise.
#=============================================================================
# >>> Test for unusual disordered atom ADP in main residue 
_215  3.0  4.0  5.0 3 I   0 0 1 0
Disordered $A   has ADP max/min Ratio ..... $F  

 The maximum and minimum main axis ADP ratio (Angstrom Units) is tested for
 the main residue. Large values may indicate unresolved disorder.
#=============================================================================
# >>> Test for unusual disordered atom ADP in minor residue
_216  5.0  7.0  9.0 3 I   0 0 1 0 
Disordered $A (An/Solv) ADP max/min Ratio   $F 

 The maximum and minimum main axis ADP ratio (Angstrom Units) is tested for
 the minor residue(s). Large values may indicate unresolved disorder.
#=============================================================================
# >>> Test for Incomplete UIJ data
_217  0.0  0.0  0.0 1 A   1 0 0 0
Incomplete U(aniso) data for ...................    $A

 Check & Correct U(aniso) data for completeness etc.
 Do not use SHELX style '=' continuation line
#=============================================================================
# >>> Test Ueq(max)/Ueq(Min) range for non-H atoms in non-solvent 
_220  3.0  6.0 10.0 2 I   0 0 1 0
Large Non-Solvent $AUeq(max)/Ueq(min) Range $F Ratio  

 This test reports on a larger than usual U(eq) range for the specified
 element type in the non-solvent/anion part of the structure.
 Too high or too low Ueq's may be an indication for incorrectly
 identified atomic species (i.e. O versus N).
#=============================================================================
# >>> Test Ueq(max)/Ueq(Min) range for non-H atoms in solvent 
_221  4.0  8.0 12.0 2 A   0 0 1 0
Large Solv./Anion $AUeq(max)/Ueq(min) Range $F Ratio  

 This test reports on a larger than usual U(eq) range for the non-hydrogen
 atoms solvent/anion. Too high or too low Ueq's may be an indication for
 incorrectly identified atomic species (i.e. Br versus Ag).
#=============================================================================
# >>> Test Uiso(max)/Uiso(Min) range for H atoms in non-solvent 
_222  4.0  7.0  9.9 3 A   0 0 1 0
Large Non-Solvent  H     Uiso(max)/Uiso(min) ... $F Ratio  
 
 This test reports on a larger than usual range of U(eq) values for hydrogen
 atoms in the non-solvent/anion part of the structure.

 Possible causes are:

 1 - disorder, e.g. in t-butyl moieties.
 2 - poor data, not adequate for the refinement of individual displacement
     parameters.
 3 - Misplaced hydrogen atoms (i.e. there is no density at the position
     where one of the H-atoms is positioned).
#=============================================================================
# >>> Test Ueq(max)/Ueq(Min) range for H atoms in solvent 
_223  3.0  4.0  5.0 4 A   0 0 1 0
Large Solvent/Anion H    Ueq(max)/Ueq(min) ..... $F Ratio  

 This test reports on large ranges in displacement parameters for hydrogen
 atoms in the solvent/anion part of the structure.
#=============================================================================
# >>> Test for difference in implicit and explicit U(eq) 
_224 .002 .003 .005 1 A   0 0 1 0
Ueq(Rep) and Ueq(Calc) differ by$A Ang**2 .        $B   

 This test reports on a large difference between Ueq in the CIF and the Ueq
 calculated from the 6 reported Uij values.                            .
#=============================================================================
# >>> Hirshfeld Rigid-Bond Test (Acta Cryst (1976),A32,239-244
_230  5.0  7.0 99.0 2 A   0 0 1 0
Hirshfeld Test Diff for    $A--  $B .. $F su 

 The components of the anisotropic displacement parameters along chemical
 bonds are assumed to be equal in magnitude. Large differences might 
 indicate contamination of these parameters with other (unresolved) effects 
 such as (substitutional) disorder, model or data errors and/or 
 over-refinement. Atomic sites assigned the wrong scattering type (e.g. Ag 
 versus Br) should generate 'problem signals' with this test. Data sets
 corrected for absorption effects with DELREF techniques (e.g. DIFABS, SHELXA,
 XABS2) often show large DELU values for bonds involving the heaviest atom.

 Note: The original 'Hirshfeld-test' was defined in absolute terms (see
 F.L.Hirshfeld, Acta Cryst. (1976). A32, 239-244). The current test is with
 reference to the associated standard uncertainty.
#=============================================================================
# >>> Hirshfeld Rigid-Bond Test (Acta Cryst (1976),A32,239-244
_231  5.0  9.0 99.0 4 A   0 0 1 0
Hirshfeld Test (Solvent)   $A--  $B .. $F su 

 The components of the anisotropic displacement parameters along chemical
 bonds are assumed to be equal in magnitude. Large differences might 
 indicate the contamination of these parameters with other (unresolved) effects 
 such as (substitutional) disorder, model or data errors and/or 
 over-refinement. Atomic sites assigned the wrong scattering type (e.g. Ag 
 versus Br) should generate 'problem signals' with this test. Data sets
 corrected for absorption effects with DELREF techniques (e.g. DIFABS, SHELXA,
 XABS2) often show large DELU values for bonds involving the heaviest atom.

 Note: The original 'Hirshfeld-test' was defined in absolute terms (see
 F.L.Hirshfeld, Acta Cryst. (1976). A32, 239-244). The current test is with
 reference to the associated standard uncertainty.
#=============================================================================
# >>> Hirshfeld Rigid-Bond Test (Metal-X) (Acta Cryst (1976),A32,239-244
_232  5.0 10.0 99.0 2 A   0 0 1 0
Hirshfeld Test Diff (M-X)  $A--  $B .. $F su 

 The components of the anisotropic displacement parameters along chemical
 bonds are assumed to be equal in magnitude. Large differences might 
 indicate contamination of these parameters with other (unresolved) effects 
 such as (substitutional) disorder, model or data errors and/or 
 over-refinement. Atomic sites assigned the wrong scattering type (e.g. Ag 
 versus Br) should generate 'problem signals' with this test. Data sets
 corrected for absorption effects with DELREF techniques (e.g. DIFABS, SHELXA,
 XABS2) often show large DELU values for bonds involving the heaviest atom.

 A special case are M-C=O type of systems that generally show significant
 differences for the M-C bond. See D.Braga & T.F. Koetzle (1988), Acta Cryst.
 B44, 151-155). 
 
 Note: The original 'Hirshfeld-test' was defined in absolute terms (see
 F.L.Hirshfeld, Acta Cryst. (1976). A32, 239-244). The current test is with
 reference to the associated standard uncertainty.
#=============================================================================
# >>> Hirshfeld Rigid-Bond Test (Metal-X) (Acta Cryst (1976),A32,239-244
_233 10.0 15.0 99.0 4 A   0 0 1 0
Hirshfeld (M-X Solvent)    $A--  $B .. $F su 

 The components of the anisotropic displacement parameters along chemical
 bonds are assumed to be equal in magnitude. Large differences might 
 indicate contamination of these parameters with other (unresolved) effects 
 such as (substitutional) disorder, model or data errors and/or 
 over-refinement. Atomic sites assigned the wrong scattering type (e.g. Ag 
 versus Br) should generate 'problem signals' with this test. Data sets
 corrected for absorption effects with DELREF techniques (e.g. DIFABS, SHELXA,
 XABS2) often show large DELU values for bonds involving the heaviest atom.

 Note: The original 'Hirshfeld-test' was defined in absolute terms (see
 F.L.Hirshfeld, Acta Cryst. (1976). A32, 239-244). The current test is with
 reference to the associated standard uncertainty.
#=============================================================================
# >>> Hirshfeld Rigid-Bond Test (Acta Cryst (1976),A32,239-244
_234 0.15 0.25  0.3 4 A   0 0 1 0
Large Hirshfeld Difference $A--  $B .. $F Ang. 

 The components of the anisotropic displacement parameters along chemical
 bonds are assumed to be equal in magnitude. Large differences might 
 indicate contamination of these parameters with other (unresolved) effects 
 such as (substitutional) disorder, model or data errors and/or 
 over-refinement. Atomic sites assigned the wrong scattering type (e.g. Ag 
 versus Br) should generate 'problem signals' with this test. Data sets
 corrected for absorption effects with DELREF techniques (e.g. DIFABS, SHELXA,
 XABS2) often show large DELU values for bonds involving the heaviest atom.

 Note: The original 'Hirshfeld-test' was defined in absolute terms (see
 F.L. Hirshfeld, Acta Cryst. (1976). A32, 239-244).
#=============================================================================
# >>> Test for unusually high U(eq) as compared with bonded neighbors 
_241 .015 0.05 0.15 2 A   0 0 1 0
High      Ueq as Compared to Neighbors for .....    $A Check

 The U(eq) value of an atom is compared with the average U(eq) for to
 non-hydrogen atoms bonded to it. Large differences may indicate that the
 wrong atom type was assigned (e.g. N instead of O).
#=============================================================================
# >>> Test for Unusually Low  U(eq) as compared with bonded neighbors 
_242 .015 0.05 0.15 2 A   0 0 1 0
Low       Ueq as Compared to Neighbors for .....    $A Check                     

 The U(eq) value of an atom is compared with the average U(eq) for 
 non-hydrogen atoms bonded to it. Large differences may indicate that the
 wrong atom type was assigned (e.g. N instead of O). False alarms may
 occur for terminal groups such as the t-butyl moiety.
#=============================================================================
# >>> Test for unusually high solvent U(eq) as compared with bonded neighbors 
_243 .015 1.00 1.00 4 A   0 0 1 0
High  'Solvent' Ueq as Compared to Neighbors of     $A Check

 The U(eq) value of an atom in the solvent or ion is compared with the average 
 U(eq) for non-hydrogen atoms bonded to it. Large differences may indicate 
 that the wrong atom type was assigned (e.g. N instead of O).
#=============================================================================
# >>> Test for unusually low solvent  U(eq) as compared with bonded neighbors 
_244 .015 1.00 1.00 4 A   0 0 1 0
Low   'Solvent' Ueq as Compared to Neighbors of     $A Check                     
 The U(eq) value of an atom in the solvent or ion is compared with the average
 U(eq) for non-hydrogen atoms bonded to it. Large differences may indicate 
 that the wrong atom type was assigned (e.g. N instead of O). False alarms may
 occur for terminal groups such as the t-butyl moiety.
#=============================================================================
# >>> Test for unusually low H-U(eq) as compared with bonded atom 
_245 0.01 0.05 0.10 2 A   0 0 1 0
U(iso) $A Smaller than U(eq) $B by ... $F AngSq                     

 U(iso) of a hydrogen atom is generally expected to be greater than the
 U(eq) of the non-hydrogen atom it is attached to.
#=============================================================================
# >>> Test for unusual anisotropic average UIJ
_250 2.00 4.00 9.00 2 A   0 0 1 0
Large U3/U1 Ratio for Average U(i,j) Tensor .... $F Note                 

 An average value of the U(i,j) tensor of the asymmetric unit of a residue
 is calculated. An ALERT is generated when the corresponding U3/U1 ratio
 deviates significantly from 1.0. Large values of this ratio should be taken
 as an indication of possible systematic errors in the data or errors in 
 the model. Visual inspection of an ORTEP plot will show that many 
 displacement ellipsoids have their major axis pointing in the same direction.
#=============================================================================
# >>> Test for main residue(s) disorder %
_301    0    0    0 3 A   0 0 1 0
Main Residue  Disorder ............ Percentage = $I Note  

 Atom sites that are not fully occupied are counted. A large fraction of
 disordered atoms may be both a signal for serious structure analysis 
 problems or less reliable/interesting results. 
#=============================================================================
# >>> Test for (anion/solvent) disorder %
_302    0    0    0 4 A   0 0 1 0 
Anion/Solvent Disorder ............ Percentage = $I Note  

 Atom sites that are not fully occupied are counted. 
#=============================================================================
# >>> Test for more than 1 connection to Hydrogen Atoms
_303    1    2    3 2 A   0 0 1 0
Full Occupancy H-Atom $A with # Connections $F Check

 Hydrogen atoms are generally connected to only one other atom. A hydrogen
 atom between two oxygen atoms is a special case. Investigate whether this
 hydrogen atom is better described with a disorder model with two partially
 occupied sites. A difference map might show a double-well density.        
#=============================================================================
# >>> Test for isolated Hydrogen Atoms
_305    0    0    0 2 A   0 0 1 0
Isolated Hydrogen Atom (Outside Bond Range ??)      $A Check 

 This test reports on hydrogen atoms that are not on bonding distance to any
 atom. This ALERT may indicate that the hydrogen atom refined to a
 non-bonding position or needs a symmetry operation to bring it to bonding
 distance. It also may indicate a problem with incompatible population 
 parameters (e.g. C - H with population 0.8 and 0.9 respectively).
#=============================================================================
# >>> Test for isolated Oxygen   Atoms
_306    0    0    2 2 A   0 0 1 0
Isolated Oxygen Atom (H-atoms Missing ?) .......    $A Check 

 This test reports on oxygen atoms that are not within bonding distance to
 any other atom in the structure. A common reason may be that no hydrogen
 atoms are given for a water molecule. Attempts should be made to locate
 those hydrogen atoms from a difference map.
#=============================================================================
# >>> Test for isolated Metal   Atoms
_307    0    0    0 2 A   0 0 1 0
Isolated Metal Atom (Unusual !) ................    $A Check 

 This test reports on metal atoms that are not bonded or at coordination
 distance of other atoms. Isolated ions are very unusual (or non-existent ?)
#=============================================================================
# >>> Test for single bonded Metal Atoms
_308    0    0    0 2 A   0 0 1 0
Single Bonded Metal Atom (Unusual !) ...........    $A Check 

 This test reports on single bonded (coordinated) metal atoms/ions. This
 represents a very unusual situation. There are literature examples where such
 a 'single bonded metal' was shown to be a halogen.
#=============================================================================
# >>> Test for single bonded Oxygen Atoms
_309    0   99   99 2 A   0 0 1 0
Single Bonded Oxygen (C-O > 1.3 Ang) ...........    $A Check 

 Single bonded Oxygen with C-O > 1.3 Angstrom. Missing H-Atom ? Check
#=============================================================================
# >>> Test for 'too close' (symmetry related) full weight atoms
_310    0    0    0 2 A   0 0 1 0 
$A Deleted (Close to $B)    Dist ..... $F Ang. 

 This test identifies (very) short contacts between atoms that only becomes
 apparent after the application of symmetry on the primary coordinate set.
#=============================================================================
# >>> Test for isolated Disordered Oxygen   Atoms
_311    0   10   10 2 A   0 0 1 0
Isolated Disordered Oxygen Atom (No H's ?) .....    $A Check 

 This test reports on oxygen atoms (not full weight) that are not within 
 bonding distance to any other atom in the structure.
 A common reason may be that no hydrogen atoms are given for a water molecule.
#=============================================================================
# >>> Test for C=O-H                        
_312    0 0.02 0.05 2 A   0 0 1 0
Strange C-O-H Geometry (C-O  <   1.25 Ang) .....    $A Check 

 Strange C-O-H geometry with C-O  <   1.25 Angstrom detected. Misplaced
 H-Atom ?
#=============================================================================
# >>> Test for O with three covalent bonds  
_313    0    2    2 2 A   0 0 1 0
Oxygen with three covalent bonds (rare) ........    $A Check 

 Oxygen atom with three covalent bonds detected. Check for correct atom type
 assignment (e.g. N rather than O)

 Note: Exceptions are H3O+ (Oximium or Hydroxonium) and
                      H5O2+ (Hydronium or aqua-hydroxonium) species.
#=============================================================================
# >>> Test for Metal-O-H angle of H2O  
_314    0    2    2 2 A   0 0 1 0
Check Small Angle for H2O: Metal-$A-$B $F Degree

 A water molecule coordinated to a metal is detected with an unusually
 small value of the Metal-Oxygen-Hydrogen Angle. 
#=============================================================================
# >>> Check for too many H's on C in C=N bond in main residue(s)
_316    0    0    0 2 A   0 0 1 0
Too many H on C in C=N Moiety in Main Residue ..    $A Check 

 An sp3 hybridized C was detected as part of a C=N moiety. Only one 
 attached H atom in sp2 configuration is expected and not two.
 In SHELXL terms this corresponds with an erroneous AFIX 23 rather than an
 AFIX 43 type of H atom position generation and refinement.
#=============================================================================
# >>> Check for too many H's on C in C=N bond in Solvent/Ion (s)
_317    0   10   10 2 A   0 0 1 0
Too many H on C in C=N Moiety in Solvent/Ion ...    $A Check

 An sp3 hybridized C was detected as part of a C=N moiety. Only one 
 attached H atom in sp2 configuration is expected and not two.
 In SHELXL terms this corresponds with an erroneous AFIX 23 rather than an
 AFIX 43 type of H atom position generation and refinement.
#=============================================================================
# >>> Hybridisation Problem on N in main residue(s)
_318    0   99   99 2 A   0 0 1 0
Hybridisation of $A in Main Residue .......     Please Check

 The test attempts to assign one of three hybridisations to N atoms in main
 residue: sp, sp2 or sp3 on the basis of the angles around N. 
 This ALERT may indicate a mis-assigned H atom position (e.g. an atom
 placed in a sp2 position instead of sp3).
#=============================================================================
# >>> Hybridisation Problem on N in solvent/ion
_319    0   99   99 2 A   0 0 1 0
Hybridisation of $A in Solvent/Ion ........     Please Check

 The test attempts to assign one of three hybridisations to N atoms in main
 residue: sp, sp2 or sp3 on the basis of the angles around N. 
 This ALERT may indicate a mis-assigned H atom position (e.g. an atom
 placed in a sp2 position instead of sp3).
#=============================================================================
# >>> Hybridisation Problem on C in main residue(s)
_320    0   99   99 2 A   0 0 1 0
Hybridisation of $A in Main Residue .......     Please Check

 The test attempts to assign one of three hybridisations to C atoms in main
 residue: sp, sp2 or sp3 on the basis of the angles around C. In this way,
 missing H atoms or too many H-atoms on a carbon atom should be detected.
#=============================================================================
# >>> Hybridisation Problem on C in solvent/ion
_321    0   99   99 2 A   0 0 1 0 
Hybridisation of $A in Solvent/Ion ........     Please Check

 The test attempts to assign one of three hybridisations to C atoms in 
 solven/anion: sp, sp2 or sp3 on the basis of the angles around C. In this 
 way missing H atoms or too many H-atoms on a carbon atom should be detected.
#=============================================================================
# >>> Hybridisation Problem on non-C in main residue(s)
_322    0   99   99 2 A   0 0 1 0 
Hybridisation of $A in Main Residue .......     Please Check 

 The test attempts to assign one of three hybridisations to a non-C atom in
 the main residue: sp, sp2 or sp3 on the basis of the angles around the
 non-C atom. In this way, missing H atoms or too many H-atoms should be 
 detected.
#=============================================================================
# >>> Hybridisation Problem on non-C in Solvent/Ion
_323    0   99   99 2 A   0 0 1 0
Hybridisation of $A in Solvent/Ion ........     Please Check

 The test attempts to assign one of three hybridisations to a non-C atom in
 the solvent/anion: sp, sp2 or sp3 on the basis of the angles around the
 non-C atom. In this way, missing H atoms or too many H-atoms should be 
 detected.
#=============================================================================
# >>> Check for possibly missing H on coordinating X-N-X in main residue
_324    0   99   99 2 A   0 0 1 0
Check for Possibly Missing H on Coordinating....    $A Check

 Check for possibly missing Hydrogen atom on Nitrogen coordinating to
 a metal in the main residue.
#=============================================================================
# >>> Check for possibly missing H on coordinating X-N-X in solvent/anion
_325    0   99   99 2 A   0 0 1 0
Check for Possibly Missing H on Coordinating....    $A Check

 Check for possibly missing Hydrogen atom on Nitrogen coordinating to
 a metal in the solvent/anion.
#=============================================================================
# >>> Check for possibly missing H on potentially sp3 Carbon            
_326    0    0   99 2 A   0 0 1 0
Possible Missing H on sp3? Carbon ..............    $A Check

 Check for possibly missing Hydrogen atom on Carbon with sp3-like geometry 
 in the main residue.
#=============================================================================
# >>> Check for possibly missing H on potentially sp3 Carbon            

_327    0    0   99 2 A   0 0 1 0
Possible Missing H on sp3? Carbon ..............    $A Check

 Check for possibly missing Hydrogen atom on Carbon with sp3-like geometry
 in the solvent/anion.
#=============================================================================
# >>> Check for a possibly missing H on potentially sp3 Phosphorus           
_328    0   99   99 4 A   0 0 1 0
Possible Missing H on sp3? Phosphorus ..........    $A Check

 Check for a possibly missing Hydrogen atom on Phosphorus with sp3-like 
 geometry. 
#=============================================================================
# >>> Check Average Phenyl C-C 
_330 0.01 0.02 0.03 2 A   0 0 1 0 
Large Average Phenyl  C-C Dist.  $A-$B $F Ang. 

 The standard average C-C bond distance in a phenyl ring is 1.395 Angstrom.
 The actual average ring distance may be larger than expected due to 
 systematic errors in the cell dimensions (e.g. use of incorrect
 wavelength value for the determination of the cell parameters).
#=============================================================================
# >>> Check Average Phenyl C-C
_331 0.02 0.03 0.04 2 A   0 0 1 0
Small Average Phenyl   C-C Dist. $A-$B $F Ang. 

 The standard average C-C bond distance in a phenyl ring is 1.395 Angstrom.
 The average ring distance may be smaller due to large thermal motion or
 incorrect cell dimensions.
#=============================================================================
# >>> Check Phenyl C-C Range
_332 0.15 0.25 0.35 2 A   0 0 1 0
Large Phenyl C-C Range           $A-$B $F Ang. 

 The standard average C-C in a phenyl ring is 1.395 Angstrom. Bond distances 
 in the ring are expected to vary only slightly due to thermal motion or
 substituent effects. Large deviations are likely due to data or model errors.
#=============================================================================
# >>> Check Average in Multiple Substituted Benzene Type C-C 
_333 0.03 0.06 0.09 2 A   0 0 1 0
Check Large Av C6-Ring C-C Dist. $A-$B $F Ang. 

 The standard average C-C bond distance in a flat six carbon atom containing
 aromatic ring is 1.395 Angstrom.
 The actual average ring distance may be larger than expected due to 
 substituents such as '=O', single bonds or systematic errors in the cell
 dimensions (E.g. when the wrong wavelength is used in the derivation of
 the cell parameters).
#=============================================================================
# >>> Check Average in Multiple Substituted Benzene Type C-C
_334 0.03 0.06 0.09 2 A   0 0 1 0
Small Average Benzene  C-C Dist. $A-$B $F Ang. 

 The standard average C-C bond distance in a benzene ring is 1.395 Angstrom.
 The average ring distance may be smaller due to large thermal motion,
 substituents such as '=O' or incorrect cell dimensions.
#=============================================================================
# >>> Check Multiple Substituted Benzene Type C-C Range
_335 0.15 0.25 0.35 2 A   0 0 1 0
Check Large C6 Ring    C-C Range $A-$B $F Ang. 

 The standard average C-C bond distance in a benzene ring is 1.395 Angstrom.
 Bond distances in the ring are expected to vary only slightly when due to 
 substituent effects (exceptions include =O substituents). Large deviations
 may indicate data or model errors.
#=============================================================================
# >>> Check Average Torsion Angle in cyclo-hexane ring
_338 25.0 45.0 60.0 4 A   0 0 1 0
Small Average Tau in cyclohexane $A-$B $F Degree

 Cyclohexane moieties should have be significantly puckered as measured by
 the average torsion angle tau. Unresolved disorder generally results in 
 flattened rings and elongated displacement ellipsoids. A disorder model
 should be included in the calculations.
#=============================================================================
# >>> Check Bond Precision for C-C in Light Atom Structures (Z(max) < 20)
_340 .004 0.01 0.05 3 A   0 0 1 0 
Low Bond Precision on  C-C Bonds ............... $F Ang.

 The average su for X-Y bonds is tested (named bond-precision). X-Y will 
 generally be C-C bonds, unless there are none. In the last case the su's of
 the lowest element numbers are considered (excluding hydrogen). There are
 three test ranges: one for structures with the largest element Z < 20, one 
 for the largest Z in the range 20 to 39 and one for structures with Z(max) 40
 or higher (_340, _341 and _342 respectively)
#=============================================================================
# >>> Check Bond Precision for C-C in Structures (19 < Z(max) < 40)
_341 .006 .015 .075 3 A   0 0 1 0
Low Bond Precision on  C-C Bonds ............... $F Ang.

 The average su for X-Y bonds is tested (named bond-precision). X-Y will 
 generally be C-C bonds, unless there are none. In the last case the su's of
 the lowest element numbers are considered (excluding hydrogen). There are
 three test ranges: one for structures with the largest element Z < 20, one 
 for the largest Z in the range 20 to 39 and one for structures with Z(max) 40
 or higher (_340, _341 and _342 respectively)
#=============================================================================
# >>> Check Bond Precision for C-C in Structures (Z(max) > 39)
_342 .008 .020 .100 3 A   0 0 1 0
Low Bond Precision on  C-C Bonds ............... $F Ang.

 The average su for X-Y bonds is tested (named bond-precision). X-Y will 
 generally be C-C bonds, unless there are none. In the last case the su's of
 the lowest element numbers are considered (excluding hydrogen). There are
 three test ranges: one for structures with the largest element Z < 20, one 
 for the largest Z in the range 20 to 39 and one for structures with Z(max) 40
 or higher (_340, _341 and _342 respectively)
#=============================================================================
# >>> Hybridisation Problem on C in main residue(s)
_343    0    0    0 2 A   0 0 1 0
Unusual $A  Angle Range in Main Residue for       $B Check 

 The angle range is larger than usual for the tentatively assigned
 hybridisation of the reported atom in the main residue. 
#=============================================================================
# >>> Hybridisation Problem on C in solvent/ion
_344    0    0    0 2 A   0 0 1 0
Unusual $A Angle Range in Solvent/Ion for .       $B Check

 The angle range is larger than usual for the tentatively assigned
 hybridisation of the reported atom in the solven/anion. 
#=============================================================================
# >>> Test for short C - H (Angstrom Difference) XRAY: 0.96 NEUT 1.08
_350 0.11  0.2  0.3 3 A   0 0 1 0
Short   C-H (X0.96,N1.08A)$A -  $B ... $F Ang. 

 Large deviations from generally accepted values may indicate model problems,
 over refinement etc.  Default C-H = 0.96 Ang. (X-Ray) value from SHELXL. 
#=============================================================================
# >>> Test for long  C - H (Angstrom Difference) XRAY: 0.96 NEUT 1.08
_351 0.14  0.2  0.3 3 A   0 0 1 0
Long    C-H (X0.96,N1.08A)$A -  $B ... $F Ang.

 Large deviations from generally accepted values may indicate model problems,
 over refinement etc.  Default C-H = 0.96 Ang. (X-Ray) value from SHELXL. 
#=============================================================================
# >>> Test for short N - H (Angstrom Difference) XRAY: 0.87 NEUT 1.009
_352  0.1  0.2  0.3 3 A   0 0 1 0 
Short   N-H (X0.87,N1.01A)$A -  $B ... $F Ang. 

 Large deviations from generally accepted values may indicate model problems,
 over refinement etc.  Default N-H = 0.87 Ang. (X-Ray) value from SHELXL. 
#=============================================================================
# >>> Test for long  N - H (Angstrom Difference) XRAY: 0.87 NEUT 1.009
_353 0.13  0.2  0.3 3 A   0 0 1 0
Long    N-H (N0.87,N1.01A)$A -  $B ... $F Ang. 

 Large deviations from generally accepted values may indicate model problems,
 over refinement etc.  Default N-H = 0.87 Ang. (X-Ray) value from SHELXL. 
#=============================================================================
# >>> Test for short O - H (Angstrom Difference) XRAY: 0.82 NEUT 0.983
_354  0.1  0.2  0.3 3 A   0 0 1 0
Short   O-H (X0.82,N0.98A)$A -  $B ... $F Ang. 

 Large deviations from generally accepted values may indicate model problems,
 over refinement etc.  Default O-H = 0.82 Ang. (X-Ray) value from SHELXL.
#=============================================================================
# >>> Test for long  O - H (Angstrom Difference) XRAY: 0.82 NEUT 0.983
_355 0.18 0.25  0.3 3 A   0 0 1 0 
Long    O-H (X0.82,N0.98A)$A -  $B ... $F Ang. 

 Large deviations from generally accepted values may indicate model problems,
 over refinement etc.  Default O-H = 0.82 Ang. (X-Ray) value from SHELXL. 
#=============================================================================
# >>> Test for short C4 - C4 (Angstrom Difference) XRAY: 1.54 
_360  0.1  0.2  0.3 2 A   0 0 1 0
Short  C(sp3)-C(sp3) Bond $A -  $B ... $F Ang. 

 Large deviations from generally accepted values may indicate model problems,
 over refinement etc. Default C4-C4 = 1.54 Ang. (X-Ray) value from
 Ladd & Palmer, Structure Determination by Xray Crystallography (1985).
 Note: 
  - C4-C4 indicates a bond between atoms with 4 bonds each.
#=============================================================================
# >>> Test for long  C4 - C4 (Angstrom Difference) XRAY: 1.54 
_361  0.1  0.2  0.3 2 A   0 0 1 0
Long   C(sp3)-C(sp3) Bond $A -  $B ... $F Ang. 

 Large deviations from generally accepted values may indicate model problems,
 over refinement etc. Default C4-C4 = 1.54 Ang. (X-Ray) value from
 Ladd & Palmer, Structure Determination by Xray Crystallography (1985).
 Note: 
  - C4-C4 indicates a bond between atoms with 4 bonds each.
#=============================================================================
# >>> Test for short C4 - C3 (Angstrom Difference) XRAY: 1.52 
_362  0.1  0.2  0.3 2 A   0 0 1 0
Short  C(sp3)-C(sp2) Bond $A -  $B ... $F Ang. 

 Large deviations from generally accepted values may indicate model problems,
 over refinement etc. Default C4-C3 = 1.52 Ang. (X-Ray) value from
 Ladd & Palmer, Structure Determination by Xray Crystallography (1985).
 Note: 
  - C4-C3 indicates a bond between an atom with 4 bonds and one with 3 bonds.
  - Conjugated systems may cause some 'false alarm' messages.
#=============================================================================
# >>> Test for long  C4 - C3 (Angstrom Difference) XRAY: 1.52 
_363  0.1  0.2  0.3 2 A   0 0 1 0
Long   C(sp3)-C(sp2) Bond $A -  $B ... $F Ang. 

 Large deviations from generally accepted values may indicate model problems,
 over refinement etc. Default C4-C3 = 1.52 Ang. (X-Ray) value from
 Ladd & Palmer, Structure Determination by Xray Crystallography (1985).
 Note: 
  - C4-C3 indicates a bond between an atom with 4 bonds and one with 3 bonds.
  - Conjugated systems may cause some 'false alarm' messages.
#=============================================================================
# >>> Test for short C4 - C2 (Angstrom Difference) XRAY: 1.46 
_364  0.1  0.2  0.3 2 A   0 0 1 0
Short  C(sp3)-C(sp)  Bond $A -  $B ... $F Ang. 

 Large deviations from generally accepted values may indicate model problems,
 over refinement etc. Default C4-C2 = 1.46 Ang. (X-Ray) value from
 Ladd & Palmer, Structure Determination by Xray Crystallography (1985).
 Note: 
  - C4-C2 indicates a bond between an atom with 4 bonds and one with 2 bonds.
  - Conjugated systems may cause some 'false alarm' messages.
#=============================================================================
# >>> Test for long  C4 - C2 (Angstrom Difference) XRAY: 1.46 
_365  0.1  0.2  0.3 2 A   0 0 1 0
Long   C(sp3)-C(sp)  Bond $A -  $B ... $F Ang. 

 Large deviations from generally accepted values may indicate model problems,
 over refinement etc. Default C4-C2 = 1.46 Ang. (X-Ray) value from
 Ladd & Palmer, Structure Determination by Xray Crystallography (1985).
 Note: 
  - C4-C2 indicates a bond between an atom with 4 bonds and one with 2 bonds.
  - Conjugated systems may cause some 'false alarm' messages.
#=============================================================================
# >>> Test for short C? - C? (Angstrom Difference) XRAY: 1.50 
_366 0.35  0.5  1.0 2 A   0 0 1 0
Short? C(sp?)-C(sp?) Bond $A -  $B ... $F Ang. 

 The hybridisation of at least one carbon atom is not recognized.
 Large deviations from generally accepted values for a C-C bond may indicate
 model problems, unresolved disorder, over_refinement etc. The C-C bond is
 tested to be not shorter than 1.15 Angstrom. 
#=============================================================================
# >>> Test for long  C? - C? (Angstrom Difference) XRAY: 1.50 
_367 0.05  0.2  0.3 2 A   0 0 1 0
Long?  C(sp?)-C(sp?) Bond $A -  $B ... $F Ang. 

 Large deviations from generally accepted values may indicate model problems,
 over refinement etc. Default C?-C? = 1.50 Ang. (X-Ray) value from
 Ladd & Palmer, Structure Determination by Xray Crystallography (1985).
#=============================================================================
# >>> Test for short C3 - C3 (Angstrom Difference) XRAY: 1.34 
_368  0.1  0.2  0.3 2 A   0 0 1 0
Short  C(sp2)-C(sp2) Bond $A -  $B ... $F Ang. 

 Large deviations from generally accepted values may indicate model problems,
 over refinement etc. Default C3-C3 = 1.34 Ang. (X-Ray) value from
 Ladd & Palmer, Structure Determination by Xray Crystallography (1985).
 Note: 
  - C3-C3 indicates a bond between atoms with 3 bonds each.
  - Conjugated systems may cause some 'false alarm' messages.
#=============================================================================
# >>> Test for long  C3 - C3 (Angstrom Difference) XRAY: 1.34 
_369 0.18 0.22  0.3 2 A   0 0 1 0
Long   C(sp2)-C(sp2) Bond $A -  $B ... $F Ang. 

 Large deviations from generally accepted values may indicate model problems,
 over refinement etc.  Default C3-C3 = 1.34 Ang. (X-Ray) value from
 Ladd & Palmer, Structure Determination by Xray Crystallography (1985).
 Note: 
  - C3-C3 indicates a bond between atoms with 4 with 3 bonds each.
  - Conjugated systems may cause some 'false alarm' messages.
  - A notable exception is the C-C bond in -C(=O)-C(=O)- systems with an 
    observed mean value of 1.54 Angstrom.
#=============================================================================
# >>> Test for short C3 - C2 (Angstrom Difference) XRAY: 1.31 
_370  0.1  0.2  0.3 2 A   0 0 1 0
Short  C(sp2)-C(sp1) Bond $A -  $B ... $F Ang. 

 Large deviations from generally accepted values may indicate model problems,
 over refinement etc. Default C3-C2 = 1.31 Ang. (X-Ray) value from
 Ladd & Palmer, Structure Determination by Xray Crystallography (1985).
 Note: 
  - C3-C2 indicates a bond between an atom with 3 bonds and one with 2 bonds.
  - Conjugated systems may cause some 'false alarm' messages.
#=============================================================================
# >>> Test for long  C3 - C2 (Angstrom Difference) XRAY: 1.31 
_371 0.1  0.2   0.3 2 A   0 0 1 0
Long   C(sp2)-C(sp1) Bond $A -  $B ... $F Ang. 

 Large deviations from generally accepted values may indicate model problems,
 over refinement etc. Default C3-C2 = 1.31 Ang. (X-Ray) value from
 Ladd & Palmer, Structure Determination by Xray Crystallography (1985).
 Note: 
  - C3-C2 indicates a bond between an atom with 3 bonds and one with 2 bonds.
  - Conjugated systems may cause some 'false alarm' messages.
#=============================================================================
# >>> Test for short C2 - C2 (Angstrom Difference) XRAY: 1.25
_372  0.1  0.2  0.3 2 A   0 0 1 0 
Short  C(sp)-C(sp)   Bond $A -  $B ... $F Ang. 

 Large deviations from generally accepted values may indicate model problems,
 over refinement etc. Default C2-C2 = 1.25 Ang. (X-Ray) value from
 Ladd & Palmer, Structure Determination by Xray Crystallography (1985).
 Note: 
  - C2-C2 indicates a bond between atoms with 2 bonds each.
  - Conjugated systems may cause some 'false alarm' messages.
#=============================================================================
# >>> Test for long  C2 - C2 (Angstrom Difference) XRAY: 1.25 
_373  0.1  0.2  0.3 2 A   0 0 1 0
Long   C(sp)-C(sp)   Bond $A -  $B ... $F Ang. 

 Large deviations from generally accepted values may indicate model problems,
 over refinement etc. Default C2-C2 = 1.25 Ang. (X-Ray) value from
 Ladd & Palmer, Structure Determination by Xray Crystallography (1985).
 Note: 
  - C2-C2 indicates a bond between atoms with 2 bonds each.
  - Conjugated systems may cause some 'false alarm' messages.
#=============================================================================
# >>> Test for long  N - N Bond  (> 1.45 Angstrom)
_374  0.0  0.0  0.0 2 A   0 0 1 0
Long   N - N         Bond $A -  $B ... $F Ang. 

 Large deviations from generally observed bond distances may indicate model
 problems, over-refinement etc. Check for wrong atom-type assignments.
 For an example see: Acta Cryst. (2003) E59, m710-m712.
#=============================================================================
# >>> Test for incorrectly Oriented Methyl Moiety  
_380  0.0 10.0 10.0 4 A   0 0 1 0
Incorrectly? Oriented X(sp2)-Methyl Moiety .....    $A Check 

 This test alerts for possible incorrectly oriented CH3 moieties.
 (E.g. AFIX 33 instead of AFIX 137 etc. within the SHELXL realm)
#=============================================================================
# >>> Test Methyl Moiety X-C-H Bond Angle 
_390  6.5  9.5 50.0 3 A   0 0 1 0
Deviating Methyl $A X-C-H Bond Angle ...... $I Degree

 Unusual Methyl Moiety X-C-H Angle (Ideally 109 Degrees for 4-bonded C).
#=============================================================================
# >>> Test Methyl Moiety H-C-H Bond Angle 
_391  7.5  9.5 50.0 3 A   0 0 1 0
Deviating Methyl $A H-C-H Bond Angle ...... $I Degree

 Unusual Methyl Moiety H-C-H Angle (ideally 109 Degrees).
#=============================================================================
# >>> Test X-O-Y Angle
_395 20.0 40.0 70.0 2 A   0 0 0 1
Deviating  X-O-Y  Angle from 120 Deg for $A $F Degree

 The X-O-Y angle is significantly larger than the expected 120.0 Degrees.
#=============================================================================
# >>> Test Si-O-Si Angle
_396 10.0 20.0 30.0 2 A   0 0 0 1
Deviating Si-O-Si Angle from 150 Deg for $A $F Degree

 The Si-O-Si angle is significantly larger than the expected 150.0 Degrees.
#=============================================================================
# >>> Test for short non-bonding intra H..H contacts
_410  0.4  0.5  0.6 2 A   0 0 0 1
Short Intra H...H Contact  $A..  $B .. $F Ang. 

 Short intramolecular contacts may arise when H-atoms are in (false)
 calculated positions. Short intramolecular contacts may also be a sign for a
 false structure with the molecule sitting on a site with improper site 
 symmetry (e.g. '2' instead of '-1') which may happen when a lattice
 translation is missed. Short contacts are defined using a van der Waals
 radius of 1.2 Angstrom. For intramolecular contacts alerts are generated
 for contacts less than 2.0 Angstrom.
#=============================================================================
# >>> Test for short non-bonding inter H..H contacts 
_411    0  0.4  0.6 2 A   0 0 0 1
Short Inter H...H Contact  $A..  $B .. $F Ang. 

 Short intermolecular H..H contacts may indicate incorrectly determined 
 structures (i.e. wrong symmetry, missed translation symmetry, wrong position 
 with reference to the symmetry elements, hydrogen atoms on atoms where there
 should not be any  etc..)
 Short intermolecular contacts may be indicative for inconsistent symmetry
 data (e.g. coordinates for space-group P43 and symmetry specified as P41 or
 P21/n & P21/c confusions). Short contacts are defined using a van der Waals
 radius of 1.2 Angstrom. For intermolecular contacts, an alert is generated
 for contacts less than 2.4 Angstrom. 
#=============================================================================
# >>> Test for short non-bonding intra H..H contacts (involving XH3)
_412  0.5  0.6  0.7 2 A   0 0 0 1
Short Intra XH3 .. XHn     $A..  $B .. $F Ang. 

 Short intramolecular contacts may arise when H-atoms are in (false)
 calculated positions. Short intramolecular contacts may also be a sign for a
 false structure with the molecule sitting on a site with improper site
 symmetry (e.g. '2' instead of '-1') which may happen when a lattice
 translation is missed. Short contacts are defined using a van der Waals
 radius of 1.2 Angstrom. Short H .. H contact involving CH3 H-atoms are often
 hampered by the fact that they involve H atoms at not optimal calculated
 positions.
#=============================================================================
# >>> Test for short non-bonding inter H..H contacts (involving XH3)
_413  0.0  0.4  0.5 2 A   0 0 0 1
Short Inter XH3 .. XHn     $A..  $B .. $F Ang. 

 Short intermolecular H..H contacts may indicate incorrectly determined 
 structures (i.e. wrong symmetry, missed translation symmetry, wrong position 
 with reference to the symmetry elements, hydrogen atoms on atoms where there
 should not be any  etc..). Short intermolecular contacts may be indicative
 for inconsistent symmetry data (e.g. coordinates for space-group P43 and
 symmetry specified as P41 or P21/n & P21/c confusions). Short contacts are
 defined using a van der Waals radius of 1.2 Angstrom. Short H .. H contact
 involving CH3 H-atoms are often hampered by the fact that they involve
 H atoms at not optimal calculated positions.
#=============================================================================
# >>> Test for short non-bonding intra D-H..H-X contacts
_414  0.4  0.5  0.6 2 A   0 0 0 1
Short Intra D-H..H-X       $A..  $B .. $F Ang. 

 Short non-bonding intra D-H..H-X contact.
#=============================================================================
# >>> Test for short non-bonding inter D-H..H-X contacts 
_415  0.1  0.3  0.5 2 A   0 0 0 1
Short Inter D-H..H-X       $A..  $B .. $F Ang. 

 Short non-bonding inter D-H..H-X contact.
#=============================================================================
# >>> Test for short non-bonding intra D-H..H-D contacts
_416  0.4  0.5  2.5 2 A   0 0 0 1
Short Intra D-H..H-D       $A..  $B .. $F Ang. 

 Short non-bonding intra D-H..H-D contacts may be related to disordered or
 misplaced H-atoms.
#=============================================================================
# >>> Test for short non-bonding inter D-H..H-D contacts 
_417    0  0.3  0.6 2 A   0 0 0 1
Short Inter D-H..H-D       $A..  $B .. $F Ang. 

 Short non-bonding inter D-H..H-D contacts may be related to disordered or
 misplaced H-atoms.

 Experience has shown that any intermolecular H...H separation of less than
 1.8 Angstroms between unit-occupancy H atoms is a clear indicator that one
 or both of these H atoms may be wrongly placed.
#=============================================================================
# >>> Test for D-H without acceptor
_420    0  1.5   99 2 A   0 0 0 1
D-H Without Acceptor       $A -  $B ..     Please Check       

 Potential hydrogen bond donors are checked for the presence of suitable 
 acceptors using commonly used (Jeffrey) H-bond criteria. As a general rule
 there should be an acceptor for each donor. Exceptions are very rare for O-H
 and more common for -NH and -NH2. A common error is an -OH on a calculated
 position pointing in the wrong direction.
#=============================================================================
# >>> Test for short non-bonding inter D...A contacts 
_430    0 0.19 0.50 2 A   0 0 0 1
Short Inter D...A Contact  $A..  $B .. $F Ang.

 This test alerts for possibly missed Hydrogen bonds as indicated by short
 (i.e. shorter than sum of the van der Waals radii - 0.2 Angstrom)
 Donor - Acceptor distances.

 Note: Short C=O .. O=C are observed sometimes when part of three-centre
 O-H, N-H or C-H O..O bridging.  
#=============================================================================
# >>> Test for short non-bonding inter HL...A contacts 
_431 0.10 0.30 0.50 2 A   0 0 0 1
Short Inter HL..A  Contact $A..  $B .. $F Ang.

 This test reports on short intermolecular Halogen .. Donor/Acceptor
 atom-type distances.
#=============================================================================
# >>> Test for short non-bonding inter X...Y contacts 
_432  0.2 0.30 0.50 2 A   0 0 0 1
Short Inter X...Y Contact  $A..  $B .. $F Ang.

 This test raised an ALERT for short intermolecular contacts.
 In general, intermolecular contact distances should be not much smaller than
 the sum of the associated van der Waals Radii. More often than not, such  
 short contacts can be a warning sign for errors. All short contacts should 
 therefore be examined in some detail. Interesting exceptions are carbonyl-
 carbonyl interactions that often feature short O...C contacts (see Allen 
 et al. (1998) B54, 320-329, short NO2 O...O interactions and BF4(-) to
 (aromatic) carbon contacts.
#=============================================================================
# >>> Test for short non-bonding minor..minor inter X...Y contacts 
_433  0.5 0.85 1.00 4 A   0 0 0 1
Short Inter X...Y Contact  $A..  $B .. $F Ang.

 This test raised an ALERT for short intermolecular contacts between minor 
 disorder components. In general, intermolecular contact distances should be 
 not much smaller than the sum of the associated van der Waals Radii. More
 often than not, such short contacts can be a warning sign for errors. All
 short contacts should therefore examined in some detail. Interesting 
 exceptions are carbonyl-carbonyl interactions that often feature short O...C 
 contacts (see Allen et al. (1998) B54, 320-329.
#=============================================================================
# >>> Test for short non-bonding inter HL...HL contacts 
_434 0.10 0.45 0.70 2 A 0 0 0 1
Short Inter HL..HL Contact $A..  $B .. $F Ang.

 This test reports on short intermolecular Halogen .. Halogen type distances. 
#=============================================================================
# >>> Test for too large H...A
_480 -.12 0.25  0.5 4 A   0 0 0 1
Long H...A H-Bond Reported $A..  $B .. $F Ang.

 Check this (unrealistically) long reported H..A contact.
 Jeffrey criterium: Contact  <   vdWR(H) + vdWR(A) - 0.12 Angstrom. 
#=============================================================================
# >>> Test for too large D...A
_481  0.5  1.0  2.0 4 A   0 0 0 1
Long D...A H-Bond Reported $A..  $B .. $F Ang.

 Check this (unrealistically) long reported D..A contact.
 Jeffrey criterium: Contact  <   vdWR(D) + vdWR(A) + 0.50 Angstrom.
#=============================================================================
# >>> Test for too small D-H...A Angle
_482  80. 90.0 100. 4 A   0 0 0 1
Small D-H..A Angle Rep for $A..  $B .. $F Degree

 Check this unrealistically small reported D-H..A Angle.
 Jeffrey criterium: D-H..A Angle > 100 degrees.
#=============================================================================
# >>> Test for not rounded D-H...A Angle
_484    0    2    2 4 I   0 0 0 1
Round D-H..A Angle Rep for $A..  $B to $I Degree

 D-H..A angles without s.u. should be rounded to integer values for
 publication purposes (Required for Acta Cryst.).
#=============================================================================
# >>> Test for (Unreported) solvent accessible voids
_601   30  100  200 2 A   0 0 0 1  
Structure Contains Solvent Accessible VOIDS of . $I Ang3 

 Crystal structures in general do not contain large solvent accessible voids
 in the lattice. Most structures lose their long-range ordering when solvent
 molecules leave the crystal. Only when the remaining network is strongly
 bonded (e.g. zeolites and some hydrogen bonded networks) the crystal 
 structure may survive.
 Residual voids in a structure may indicate the omission of (disordered) 
 density from the model. Disordered density may go undetected when smeared
 since peak search programs are not designed to locate maxima on density
 ridges. The presence or absence of residual density in the void may be
 verified on a printed/plotted difference Fourier map or with PLATON/SQUEEZE.
 Voids of 40 Ang**3 may accommodate H2O. Small molecules such as 
 Tetrahydrofuran have typical volumes in the 100 to 200 Ang**3 range.
 This test reports the volume of the largest solvent accessible void in the
 structure.
 A paper reporting a crystal structure with a significant solvent accessible 
 void should at the least discuss the issue.
#=============================================================================
# >>> Test for TOO LARGE (Unreported) solvent accessible voids
_602    0    0    0 2 A   0 0 0 1       
VERY LARGE Solvent Accessible VOID(S) in Structure        ! Info

 This test reports on a solvent accessible void in the structure, too large 
 or too time consuming for the current PLATON version for a more detailed
 analysis as part of the validation run. Use the SOLV option for more details.
 Such a warning might also indicate that the symmetry is incomplete
 e.g. should have been specified as P-1 and not P1, leaving out half of
 the unit cell content.
#=============================================================================
# >>> Test for TOO LARGE Unit Cell for VOID search 
_603    0    0    0 4   A 0 0 0 1     
Unit Cell TOO large for VOID SEARCH in Structure          ! Info

 No search for solvent accessible VOIDS done as part of VALIDATION in 
 view of large unit-cell. 
#=============================================================================
# >>> Test for TOO Many VOIDS                      
_604    0    0    0 4 A   0 0 0 1       
Too Many VOIDS Detected in Structure .............        ! Info

 Too many solvent accessible VOIDS. 
# ============================================================================
# >>> Test for (Reported)  solvent accessible voids
_605    0    0    0 4 A   0 0 0 1  
Structure Contains Solvent Accessible VOIDS of . $I A**3 

 Crystal structures in general do not contain large solvent accessible voids
 in the lattice. Most structures lose their long-range ordering when solvent
 molecules leave the crystal. Only when the remaining network is strongly
 bonded (e.g. zeolites and some hydrogen bonded networks) the crystal 
 structure may survive.
 Residual voids in a structure may indicate the omission of (disordered) 
 density from the model. Disordered density may go undetected when smeared
 since peak search programs are not designed to locate maxima on density
 ridges. The presence or absence of residual density in the void may be
 verified on a printed/plotted difference Fourier map or with PLATON/SQUEEZE.
 Voids of 40 Ang**3 may accommodate H2O. Small molecules such as 
 Tetrahydrofuran have typical volumes in the 100 to 200 Ang**3 range.
 This test reports the volume of the largest solvent accessible void in the
 structure.
 A paper reporting a crystal structure with a significant solvent accessible 
 void should at the least discuss the issue.

 Note: The use of PLATON/SQUEEZE was reported in the CIF
#=============================================================================
# >>> Test for TOO LARGE (Reported) solvent accessible voids
_606    0    0    0 4 A   0 0 0 1       
VERY LARGE Solvent Accessible VOID(S) in Structure        ! Info

 This test reports on a solvent accessible void in the structure, too large 
 or too time consuming for the current PLATON version for a more detailed
 analysis as part of the validation run. Use the SOLV option for more details.
 Such a warning might also indicate that the symmetry is incomplete
 e.g. should have been specified as P-1 and not P1, leaving out half of
 the unit cell content.
#=============================================================================
# >>> Test for consistency of Bonds and Coordinates in CIF
_701  1.0  2.0  3.0 1 A   0 0 0 1          
Bond    Calc$X, Rep$Y, Dev.. $F Sigma 

 Bond distances given in the CIF are cross-checked with corresponding
 values calculated from the coordinates.  Alerts are set at 1,2 and 3 sigma
 deviation levels.
 Note: Default s.u.'s are used where no su given (e.g. for C-H)
 In general, all differences should be within the associated s.u.
 Small differences may arise from rounding.
 Very large deviation (or zero distance) normally indicate incorrectly 
 specified symmetry operations on the associated atoms, or 'cut-and-pasting'
 of incompatible CIF's.
#=============================================================================
# >>> Test for consistency of Angles and Coordinates in CIF
_702  1.0  2.0  3.0 1 A   0 0 0 1         
Angle   Calc$X, Rep$Y, Dev.. $F Sigma 

 Bond Angles given in the CIF are cross-checked with corresponding values
 calculated from the coordinates.  Alerts are set at 1,2 and 3 sigma 
 deviation levels.
 In general, all differences should be within the associated s.u.
 Small differences may arise from rounding. Very large deviations normally
 indicate incorrectly specified symmetry operations on the associated atoms,
 or 'cut-and-pasting' of incompatible CIF's.
#=============================================================================
# >>> Test for consistency of Torsions and Coordinates in CIF
_703  1.0  2.0  3.0 1 A   0 0 0 1          
Torsion Calc$X, Rep$Y, Dev.. $F Sigma 

 Torsion angles given in the CIF are cross-checked with corresponding values
 calculated from the coordinates.  Alerts are set at 1,2 and 3 sigma 
 deviation levels.
 In general, all differences should be within the associated s.u.
 Small differences may arise from rounding. Very large deviations normally
 indicate incorrectly specified symmetry operations on the associated atoms,
 or 'cut-and-pasting' of incompatible CIF's.
#=============================================================================
# >>> Test for consistency of Contact Distances and Coordinates in CIF
_704  1.0  2.0  3.0 1 A   0 0 0 1          
Contact Calc$X, Rep$Y, Dev.. $F Sigma 

 Intermolecular contacts listed in the CIF are checked against the
 coordinates in the CIF.
 Alerts are set at 1,2 and 3 sigma deviation levels.
#=============================================================================
# >>> Test for consistency of H-Bond D-H distances and Coordinates in CIF
_705  1.0  2.0  3.0 1 A   0 0 0 1           
D-H     Calc$X, Rep$Y, Dev.. $F Sigma 

 Hydrogen-Bond D-H listed in the CIF is checked.  Alerts are set at
 1,2 and 3 sigma deviation levels.
#=============================================================================
# >>> Test for consistency of H-Bond H..A Distances and Coordinates in CIF
_706  1.0  2.0  3.0 1 A   0 0 0 1           
H...A   Calc$X, Rep$Y, Dev.. $F Sigma 

 Hydrogen-Bond H..A listed in the CIF is checked. Alerts are set at 1,2 and
 3 sigma deviation levels.

 This ALERT is generally related to incorrect symmetry codes. The symmetry 
 number s in the symmetry code s_pqr should correspond to the expression 
 for s in the CIF. Those expressions can be different for different 
 software packages. E.g. pasting H-bond table data generated with PLATON
 into a CIF generated with SHELXL may raise this ALERT. Manual correction 
 of the symmetry code should be trivial.
#=============================================================================
# >>> Test for consistency of H-Bond D..A Distances and Coordinates in CIF
_707  1.0  2.0  3.0 1 A   0 0 0 1           
D...A   Calc$X, Rep$Y, Dev.. $F Sigma 

 Hydrogen-Bond D..A listed in the CIF is checked. Alerts are set at 1,2 and
 3 sigma deviation levels.

 This ALERT is generally related to incorrect symmetry codes. The symmetry 
 number s in the symmetry code s_pqr should correspond to the expression 
 for s in the CIF. Those expressions can be different for different 
 software packages. E.g. pasting H-bond table data generated with PLATON
 into a CIF generated with SHELXL may raise this ALERT. Manual correction 
 of the symmetry code should be trivial.
#=============================================================================
# >>> Test for consistency of H-Bond D-H..A Angles and Coordinates in CIF
_708  1.0  2.0  3.0 1 A   0 0 0 1          
D-H..A  Calc$X, Rep$Y, Dev.. $F Sigma 

 Hydrogen-Bond Angle D-H..A listed in the CIF is checked. Alerts are set at
 1,2 and 3 sigma deviation levels.

 This ALERT is generally related to incorrect symmetry codes. The symmetry 
 number s in the symmetry code s_pqr should correspond to the expression 
 for s in the CIF. Those expressions can be different for different 
 software packages. E.g. pasting H-bond table data generated with PLATON
 into a CIF generated with SHELXL may raise this ALERT. Manual correction 
 of the symmetry code should be trivial.
#=============================================================================
# >>> Test for Linear Torsions in CIF
_710    0    0    0 4 I   0 0 0 1       
Delete 1-2-3 or 2-3-4 Linear Torsion Angle ... #    $A Do ! 

 Torsion angles specified in the CIF are checked for the
 'linear variety' where one or both of the 1-2-3 and 2-3-4 bond
 angles are close to 180 Deg. SHELXL97 will generate those 'torsions' for
 molecules containing linear moieties (E.g. Metal-C=O).
#=============================================================================
# >>> Test for label problems for Bonds in CIF
_711    0   99   99 1 A   0 0 0 1           
BOND    Unknown or Inconsistent Label ..........    $A 

 When labels are found on geometry items (bonds, angles etc.) that are not in
 the coordinate list, and alert _71n is issued, related to alert _70n.
#=============================================================================
# >>> Test for label problem for Angles in CIF
_712    0   99   99 1 A   0 0 0 1            
ANGLE   Unknown or Inconsistent Label ..........    $A 

 When labels are found on geometry items (bonds, angles etc.) that are not in
 the coordinate list, and alert _71n is issued, related to alert _70n.
#=============================================================================
# >>> Test for label problem for Torsions in CIF
_713    0   99   99 1 A   0 0 0 1           
TORSION Unknown or Inconsistent Label ..........    $A 

 When labels are found on geometry items (bonds, angles etc.) that are not in
 the coordinate list, and alert _71n is issued, related to alert _70n.
#=============================================================================
# >>> Test for label problem for Contact Distances in CIF
_714    0   99   99 1 A   0 0 0 1            
CONTACT Unknown or Inconsistent Label ..........    $A 

 When labels are found on geometry items (bonds, angles etc.) that are not in
 the coordinate list, and alert _71n is issued, related to alert _70n.
#=============================================================================
# >>> Test for label problem for H-Bond D-H distances in CIF
_715    0   99   99 1 A   0 0 0 1          
D-H     Unknown or Inconsistent Label ..........    $A

 When labels are found on geometry items (bonds, angles etc.) that are not in
 the coordinate list, and alert _71n is issued, related to alert _70n.
#=============================================================================
# >>> Test for label problem for H-Bond H..A Distances in CIF
_716    0   99   99 1 A   0 0 0 1           
H...A   Unknown or Inconsistent Label ..........    $A 

 When labels are found on geometry items (bonds, angles etc.) that are not in
 the coordinate list, and alert _71n is issued, related to alert _70n.
#=============================================================================
# >>> Test for label problem for  H-Bond D..A Distances in CIF
_717    0   99   99 1 A   0 0 0 1           
D...A   Unknown or Inconsistent Label ..........    $A 

 When labels are found on geometry items (bonds, angles etc.) that are not in
 the coordinate list, and alert _71n is issued, related to alert _70n.
#=============================================================================
# >>> Test for label problem for H-Bond D-H..A Angles in CIF
_718    0   99   99 1 A   0 0 0 1          
D-H..A  Unknown or Inconsistent Label ..........    $A

 When labels are found on geometry items (bonds, angles etc.) that are not in
 the coordinate list, and alert _71n is issued, related to alert _70n.
#=============================================================================
# >>> Test for Unusual Labels
_720    0    2    2 4 I   0 0 0 1
Number of Unusual/Non-Standard Labels .......... $I Note

 Up to 4 Character Labels of the type C11, H101, N10A, i.e. chemical symbol +
 number + optional letter are to be preferred.
#=============================================================================
# >>> Test for consistency of Bonds and Coordinates in CIF
_721  1.0  2.0  3.0 1 A   0 0 0 1
Bond    Calc$X, Rep$Y Dev... $F Ang.  

 Same as 701 but for distance without su (esd). Difference is tested in terms
 of Angstroms.
#=============================================================================
# >>> Test for consistency of Angles and Coordinates in CIF
_722  1.0  2.0  3.0 1 A   0 0 0 1
Angle   Calc$X, Rep$Y Dev... $F Degree

 Same as 702 but for angle without su (esd). Difference is tested in terms of
 Degrees.
#=============================================================================
# >>> Test for consistency of Torsions and Coordinates in CIF
_723  1.0 999. 999. 1 A   0 0 0 1
Torsion Calc$X, Rep$Y Dev... $F Sigma 

 Same as 703 but for torsion without su (esd). Difference is tested in terms 
 of Degrees.
#=============================================================================
# >>> Test for consistency of Contact Distances and Coordinates in CIF
_724  1.0  2.0  3.0 2 A   0 0 0 1
Contact Calc$X, Rep$Y Dev... $F Ang.  

 Same as 704, but for distance without su (esd). Difference is tested in 
 terms of Angstroms.
#=============================================================================
# >>> Test for consistency of H-Bond D-H distances and Coordinates in CIF
_725  1.0  2.0  3.0 2 A   0 0 0 1
D-H     Calc$X, Rep$Y Dev... $F Ang.  

 Same as 705 but for distance without s.u. (esd). Differences are tested in
 terms of Angstrom.
#=============================================================================
# >>> Test for consistency of H-Bond H..A Distances and Coordinates in CIF
_726  1.0  2.0  3.0 2 A   0 0 0 1
H...A   Calc$X, Rep$Y Dev... $F Ang. 

 Same as 706 but for distance without s.u. (esd). Differences are tested in 
 terms of Angstrom.
#=============================================================================
# >>> Test for consistency of H-Bond D..A Distances and Coordinates in CIF
_727  1.0  2.0  3.0 1 A   0 0 0 1
D...A   Calc$X, Rep$Y Dev... $F Ang.  

 Same as 707 but for distance without s.u. (esd). Differences are tested in
 terms of Angstrom.
#=============================================================================
# >>> Test for consistency of H-Bond D-H..A Angles and Coordinates in CIF
_728  1.0  2.0  3.0 1 A   0 0 0 1
D-H..A  Calc$X, Rep$Y Dev... $F Degree

 Same as ALERT 708 but for angle without s.u. (esd). Differences are tested  
 in terms of Degrees.
#=============================================================================
# >>> Test for consistency of Bond su's and Coordinate su's in CIF
_731  3.0  6.0 12.0 1 A   0 0 0 1
Bond    Calc$X, Rep$Y ...... $I su-Ratio 

 A large ratio of the reported and calculated bond s.u.'s is found. 
 The use of a DFIX instruction might cause such a warning since
 calculated s.u.'s are based on reported variances only.
 Note_1: su's on the unit-cell dimensions are taken into account in the
 calculation of expected su's. This may result in large differences 
 between expected and reported su's when this contribution is not included
 in the reported su's, in particular for inaccurate unit-cells.
 Note_2: Another source for the discrepancy between calculated and 
 reported su's can be that the validation software has access only to
 the variances of the refined parameters as opposed to the full co-variance
 matrix used by e.g. SHELXL for the calculation of derived parameters
 with associated su's. Constrained/restrained refinement may cause large
 co-variances.  
#=============================================================================
# >>> Test for consistency of Angles and Coordinates in CIF s.u.'s
_732  2.0  4.0  8.0 1 A   0 0 0 1
Angle   Calc$X, Rep$Y ...... $F su-Ratio 

 A large ratio of the reported and calculated bond angle s.u.'s is found. 
 This check should warn for erroneous rounding: E.g. 105.5(19) to 105.5(2) or 
 105.0(5) to 105(5) etc. Note: Large differences are possible when certain
 constraints/restraints were applied in the refinement (e.g. the FLAT option 
 in SHELXL97).
 Note: su's on the unit-cell dimensions are taken into account in the
 calculation of expected su's. This may result in large differences 
 between expected and reported su's when this contribution is not included
 in the reported su's, in particular for inaccurate unit-cells.
 Note_2: Another source for the discrepancy between calculated and 
 reported su's can be that the validation software has access only to
 the variances of the refined parameters as opposed to the full co-variance
 matrix used by e.g. SHELXL for the calculation of derived parameters
 with associated su's. Constrained/restrained refinement may cause large
 co-variances.  
#=============================================================================
# >>> Test for consistency of Torsions and Coordinates in CIF  s.u's
_733  4.0  6.0  8.0 1 A   0 0 0 1
Torsion Calc$X, Rep$Y ...... $F su-Ratio 

 A large ratio of the reported and calculated torsion angle s.u.'s is found. 
 This check should warn for erroneous rounding: E.g. 105.5(19) to 105.5(2) 
 or 105.0(5) to 105(5) etc.
 Note: su's on the unit-cell dimensions are taken into account in the
 calculation of expected su's. This may result in large differences 
 between expected and reported su's when this contribution is not included
 in the reported su's, in particular for inaccurate unit-cells.
 Note_2: Another source for the discrepancy between calculated and 
 reported su's can be that the validation software has access only to
 the variances of the refined parameters as opposed to the full co-variance
 matrix used by e.g. SHELXL for the calculation of derived parameters
 with associated su's. Constrained/restrained refinement may cause large
 co-variances.  
#=============================================================================
# >>> Test for consistency of Contact Distance s.u. and Coordinate s.u. in CIF
_734  2.0  4.0  8.0 1 A   0 0 0 1
Contact Calc$X, Rep$Y ...... $F su-Ratio 

 A large ratio of the reported and calculated contact distance s.u.'s is found. 
 Note: su's on the unit-cell dimensions are taken into account in the
 calculation of expected su's. This may result in large differences 
 between expected and reported su's when this contribution is not included
 in the reported su's, in particular for inaccurate unit-cells.
#=============================================================================
# >>> Test for consistency of H-Bond D-H distance s.u. and Coordinate s.u in CIF
_735  2.0  4.0  8.0 1 A   0 0 0 1
D-H     Calc$X, Rep$Y ...... $I su-Ratio 

 A large ratio of the reported and calculated H-bond D-H distance s.u.'s is
 found. The use of a DFIX instruction might cause such a warning since
 calculated s.u.'s are based on reported variances only.
 Note: su's on the unit-cell dimensions are taken into account in the
 calculation of expected su's. This may result in large differences 
 between expected and reported su's when this contribution is not included
 in the reported su's, in particular for inaccurate unit-cells.
#=============================================================================
# >>> Test for consistency of H-Bond H..A Distance s.u. and Coordinates in CIF
_736  2.0  4.0  8.0 1 A   0 0 0 1 
H...A   Calc$X, Rep$Y ...... $F su-Ratio 

 A large ratio of the reported and calculated H-bond H..A distance s.u.'s 
 is found.
 Note: su's on the unit-cell dimensions are taken into account in the
 calculation of expected su's. This may result in large differences 
 between expected and reported su's when this contribution is not included
 in the reported su's, in particular for inaccurate unit-cells.
#=============================================================================
# >>> Test for consistency of H-Bond D..A Distance s.u. and Coordinates in CIF
_737  2.0  4.0  8.0 1 A   0 0 0 1 
D...A   Calc$X, Rep$Y ...... $F su-Ratio 

 A large ratio of the reported and calculated H-Bond D...A distance s.u.'s is
 found. 
#=============================================================================
# >>> Test for consistency of H-Bond D-H..A Angle and Coordinates in CIF s.u.
_738  2.0  4.0  8.0 1 A   0 0 0 1
D-H..A  Calc$X, Rep$Y ...... $F su-Ratio 

 A large ratio of the reported and calculated H-Bond D-H..A angle s.u.'s 
 is found. 
 Note: su's on the unit-cell dimensions are taken into account in the
 calculation of expected su's. This may result in large differences 
 between expected and reported su's when this contribution is not included
 in the reported su's, in particular for inaccurate unit-cells.
#=============================================================================
# >>> Test for missing Bond su in CIF
_741  0.0 99.0 99.0 1 A   0 0 0 1
Bond    Calc$X, Rep$Y ......    Missing su

 Likely missing s.u. on Bond in CIF.
#=============================================================================
# >>> Test for missing Angle s.u. in CIF 
_742  0.0 99.0 99.0 1 A   0 0 0 1
Angle   Calc$X, Rep$Y ......    Missing su

 Likely missing s.u. on Bond angle in CIF.
#=============================================================================
# >>> Test for missing Torsion s.u. in CIF  
_743  0.0 99.0 99.0 1 A   0 0 0 1
Torsion Calc$X, Rep$Y ......    Missing su

 Likely missing s.u. on Torsion angle in CIF.
#=============================================================================
# >>> Test for missing Contact Distance s.u.  in CIF
_744  0.0 99.0 99.0 1 A   0 0 0 1
Contact Calc$X, Rep$Y ......    Missing su

 Likely missing s.u. on contact Distance in CIF.
#=============================================================================
# >>> Test for missing H-Bond D-H distance s.u. in CIF
_745  0.0 99.0 99.0 1 A   0 0 0 1
D-H     Calc$X, Rep$Y ......    Missing su

 Likely missing s.u. on H-Bond D-H distance in CIF.
#=============================================================================
# >>> Test for missing H-Bond H..A Distance s.u. in CIF
_746  0.0 99.0 99.0 1 A   0 0 0 1
H...A   Calc$X, Rep$Y ......    Missing su
 
 Likely missing s.u. on H-Bond H...A distance in CIF.
#=============================================================================
# >>> Test for missing H-Bond D..A Distance s.u. in CIF
_747  0.0 99.0 99.0 1 A   0 0 0 1
D...A   Calc$X, Rep$Y ......    Missing su

 Likely missing s.u. on H-Bond D...A distance in CIF.
#=============================================================================
# >>> Test for missing H-Bond D-H..A Angle s.u. in CIF 
_748  0.0 99.0 99.0 1 A   0 0 0 1 
D-H..A  Calc$X, Rep$Y ......    Missing su

 Likely missing s.u. on H-Bond D-H..A angle in CIF.
#=============================================================================
# >>> Test for senseless Bond s.u. in CIF
_751  0.0 99.0 99.0 4 A   0 0 0 1
Bond    Calc$X, Rep$Y ......  Senseless su

 An s.u. should not be given in the CIF for constrained distances.
 Please check for proper refinement status flags (e.g. R)
#=============================================================================
# >>> Test for senseless Angle s.u. in CIF
_752  0.0 99.0 99.0 4 A   0 0 0 1
Angle   Calc$X, Rep$Y ......  Senseless su

 An s.u. should not be given in the CIF for constrained angles.
 Please check for proper refinement status flags (e.g. R)
#=============================================================================
# >>> Test for senseless Torsion s.u. in CIF  
_753  0.0 99.0 99.0 4 A   0 0 0 1
Torsion Calc$X, Rep$Y ......  Senseless su

 An s.u. should not be given in the CIF for constrained torsion angles.
 Please check for proper refinement status flags (e.g. R)
#=============================================================================
# >>> Test for senseless Contact Distance s.u.  in CIF
_754  0.0 99.0 99.0 4 A   0 0 0 1
Contact Calc$X, Rep$Y ......  Senseless su

 An s.u. should not be given in the CIF for constrained contact distances.
 Please check for proper refinement status flags (e.g. R)
#=============================================================================
# >>> Test for senseless  H-Bond D-H distance s.u. in CIF
_755  0.0 99.0 99.0 4 A   0 0 0 1
D-H     Calc$X, Rep$Y ......  Senseless su

 An s.u. should not be given in the CIF for constrained distances.
 Please check for proper refinement status flags (e.g. R)
#=============================================================================
# >>> Test for senseless  H-Bond H..A Distance s.u. in CIF
_756  0.0 99.0 99.0 4 A   0 0 0 1   
H...A   Calc$X, Rep$Y ......  Senseless su

 An s.u. should not be given in the CIF for constrained distances.
 Please check for proper refinement status flags (e.g. R)
#=============================================================================
# >>> Test for senseless  H-Bond D..A Distance s.u. in CIF
_757  0.0 99.0 99.0 4 A   0 0 0 1     
D...A   Calc$X, Rep$Y ......  Senseless su

 An s.u. should not be given in the CIF for constrained distances.
 Please check for proper refinement status flags (e.g. R)
#=============================================================================
# >>> Test for Senseless  H-Bond D-H..A Angle s.u. in CIF 
_758  0.0 99.0 99.0 4 A   0 0 0 1      
D-H..A  Calc$X, Rep$Y ......  Senseless su

 An s.u. should not be given in the CIF for constrained angles.
 Please check for proper refinement status flags (e.g. R)
#=============================================================================
# >>> Test for the presence of at least one torsion angle in the CIF 
_760    0    2    2 1 I   0 0 0 1          
CIF Contains no Torsion Angles .................          ? Info

 The CIF contains no torsion angle entries. This might be accomplished with 
 the SHELXL instruction CONF. 
 Inclusion is encouraged by Acta Cryst. but not necessarily so by other
 journals.
#=============================================================================
# >>> Test for the presence of at least one X-H in the CIF 
_761    0    2    2 1 I   0 0 0 1          
CIF Contains no X-H Bonds ......................     Please Check

 The CIF contains no X-H Bonds. This might be caused by not using the
 SHELXL instruction BOND $H. Inclusion is required by Acta Cryst. but not
 necessarily so by other journals.
#=============================================================================
# >>> Test for at least one X-Y-H or H-Y-H entry in the CIF 
_762    0    2    2 1 I   0 0 0 1       
CIF Contains no X-Y-H or H-Y-H Angles ..........     Please Check

 The CIF contains no X-Y-H or H-Y-H bond angles. This might be caused by not
 using the SHELXL instruction BOND $H. Those data should also be supplied
 when H-atoms are introduced on calculated positions and/or refined riding
 on their carrier atom.  
 Inclusion is required by Acta Cryst. but not necessarily so by other journals.
#=============================================================================
# >>> Test for missing bonds in CIF                         
_763 0.01  0.1  5.0 1 I   0 0 0 1     
Incomplete CIF Bond list Detected (Rep/Expd) ... $F Ratio   

 Bond list in CIF likely incomplete.
#=============================================================================
# >>> Test for overcomplete bonds in CIF                         
_764  0.0  5.0  5.0 4 I   0 0 0 1     
Overcomplete CIF Bond List Detected (Rep/Expd) . $F Ratio   

 The CIF contains more bonds than the unique set, indicating redundancy. 
 An example is redundancy due to the inclusion of symmetry related bonds.
#=============================================================================
# >>> Test for suspect C-H bonds in CIF (Not caught otherwise)
_770  0.0  0.0  0.0 2 A   0 0 0 1   
Suspect C-H Bond in CIF:   $A--  $B .. $F Ang. 

 Report on unusual C-H bonds not caught in other tests. 
#=============================================================================
# >>> Test for suspect N-H bonds in CIF (Not caught otherwise)
_771  0.0  0.0  0.0 2 A   0 0 0 1  
Suspect N-H Bond in CIF:   $A--  $B .. $F Ang. 

 Report on unusual N-H bonds not caught in other tests.
#=============================================================================
# >>> Test for suspect O-H bonds in CIF (Not caught otherwise)
_772  0.0  1.4  1.5 2 A   0 0 0 1    
Suspect O-H Bond in CIF:   $A--  $B .. $F Ang. 

 Report on unusual O-H bonds not caught in other tests.

 Note: Exceptions can be H-atoms in acid O..H..O bridges or in H5O2+
       (Hydronium) species.
#=============================================================================
# >>> Test for suspect C-C bonds in CIF (Not caught otherwise)
_773  0.0  0.0  0.0 2 A   0 0 0 1     
Check long C-C Bond in CIF: $A--  $B . $F Ang. 

 Report on unusual C-C bonds, possibly  not caught in other tests.
 Exceptions include C-C distances of around 1.75 Ang. in e.g.
 1,2-dicarba-closo-dodecaborane.
#=============================================================================
# >>> Test for too large / erroneous bond distance            
_774  3.5  4.0 99.0 1 A   0 0 0 1      
Suspect X-Y Bond in CIF:   $A--  $B .. $F Ang. 

 Likely Erroneous Bond Entry. 
#=============================================================================
# >>> Test for too large / erroneous Contact distance            
_775  4.0  6.0 99.0 1 A   0 0 0 1     
Suspect X-Y Cont in CIF:   $A--  $B .. $F Ang. 

 Likely Erroneous Contact Entry. 
#=============================================================================
# >>> Test for too large / erroneous H-Bond D-H  distance            
_776  1.3  1.5  2.0 1 A   0 0 0 1     
Suspect D-H Dist in CIF:   $A--  $B .. $F Ang. 

 Likely Erroneous D-H Entry. 
#=============================================================================
# >>> Test for suspect Angle in CIF (Not caught otherwise)
_779  0.0  0.0  0.0 4 I   0 0 0 1    
Suspect or Irrelevant (Bond) Angle in CIF .... #    $A Check

 Possibly erroneous (Bond)angle less than 45 degree. The angle might be
 considered for elimination from the CIF when irrelevant. This ALERT can
 also be triggered when the assigned occupancy factors are incorrect.
#=============================================================================
# >>> Test whether coordinates form a connected set
_780    0    0  1.0 1 A   0 1 0 0        
Coordinates do not Form a Properly Connected Set     Please Do !

 Atoms given in a CIF should form a 'connected set', i.e. no symmetry 
 operations are needed to get atoms in a bonding position. A connected set of
 atoms is not needed for the least squares refinement (unless hydrogen atoms
 are to be added at calculated positions). Geometry listings (bonds, angles,
 torsions & H-bonds) become unwieldy for non-connected atom sets.
#=============================================================================
# >>> Test for Flack x value for Centrosymmetric space-group
_781    0    0    0 1 A   0 0 0 1       
Flack Parameter is given for Centro Space group.          ? Error

 A Flack parameter value is erroneously given for a structure reported
 in a centrosymmetric space-group.
#=============================================================================
# >>> Test for Unusual C-NO2 an C-CO2 moiety Bond geometry
_782    0  1.0  2.0 2 A   0 0 1 0       
Unusual Bond Geometry for  $A Moiety Around    $B Check

 Warning for a possible misassignment of C-NO2 and C-CO2 moieties.
 The geometry of the reported moiety appears to be unusual/inconsistent.
 The C-O bond distances in C-CO2 are expected to add up to about 2.5
 Test Criteria: ALERT for C-O bond sum < 2.48 and C-C < 1.48 Angstrom
 The N-O bond distances in C-NO2 are expected to add up to about 2.4
 Test Criteria: ALERT for N-O bond sum > 2.48 and C-C > 1.48 Angstrom
#=============================================================================
# >>> Report the number of atoms with negative _atom_site_disorder_group #
_789    0    0    0 4 I   0 0 0 1
Atoms with Negative _atom_site_disorder_group  # $I Check
 
 A negative value of the _atom_site_disorder_group number of an atom indicates
 whether that atom is part of a group disordered over a symmetry element.
 Check whether this negative sign assignment applies. 
#=============================================================================
# >>> Test Whether C.G. Residue in Unitcell Box
_790    0    2    2 4 I   0 0 0 1        
Centre of Gravity not Within Unit Cell: Resd.  # $I Note

 Unless for a good reason, molecular species should be transformed
 (by symmetry and/or translation) so that their centres of gravity
 are close to or within the unit-cell bounds. This is a strict rule for the
 main species. Deviations from this general rule are for smaller additional
 species when relevant for intermolecular interactions with the main species.
#=============================================================================
# >>> Check the absolute configuration of chiral atom in 'chiral' spgr   
_791    0    0    0 4 I   0 0 0 1
The Model has Chirality at $A (Chiral SPGR)    $B Verify

 This test addresses the consistency of the absolute configuration 
 assignment in non-centrosymmetric structures with proper symmetry 
 operations (i.e. all matrices with determinant = 1) only.

 Verify the (R/S) absolute configuration assignment of this atom and
 the consistency of the absolute configuration implicit in the CIF-data 
 with that in the 'ORTEP' illustration. Torsion angles should have the
 correct sign.

 The absolute structure assignment should also be consistent with the 
 lowest value of the Flack parameter and/or know absolute configuration.
#=============================================================================
# >>> Check the absolute configuration of chiral atom in 'non-chiral' spgr   
_792    0    0    0 1 I   0 0 0 1
The Model has Chirality at $A (Polar  SPGR)    $B Verify

 This test addresses the consistency of the absolute structure assignment
 (i.e. polarity etc.) in non-centrosymmetric structures in space groups
 that include improper symmetry operations (e.g. mirror planes).
 
 Check the (R/S) absolute configuration assignment of this atom and
 the consistency of the absolute configuration implicit in the CIF-data 
 with that in the 'ORTEP' illustration.
#=============================================================================
# >>> Check the absolute configuration of chiral atom in centrosymmetric spgr   
_793    0    0    0 4 A   0 0 0 1
The Model has Chirality at $A (Centro SPGR)    $B Verify

 This test addresses the consistency of the absolute configuration assignment
 of molecules in the reported asymmetric unit among coordinates,
 molecular presentations and chemical diagrams.

 Check the (R/S) absolute configuration assignment of this atom and
 the consistency of the absolute configuration implicit in the CIF-data 
 with that in the 'ORTEP' illustration.
#=============================================================================
# >>> Report the calculated 'Valence Bond' valency for metals
_794    0    0    0 5 A   0 0 0 1
Tentative Bond Valency for $A $B ..... $F Note

 This test reports the valency of an atom as predicted by the Valence
 Bond Model. See: 
 N.E. Brese & M. O'Keeffe (1991) Acta Cryst. B47, 192-197.
 I.D. Brown (2002). The Chemical Bond in Inorganic Chemistry: 
      The Bond Valence Model. Oxford University Press.

 More explicit info on the calculations can be obtained by running the
 calculations explicitly with the PLATON option BondValence.

 Note: The underlying theory is empirical and might not apply to the
       case at hand (e.g. charged species).
#=============================================================================
# >>> Test for C-atom Labels Ordered
_795  0.0  0.0  0.0 4 I   0 0 0 1                              
C-Atom in CIF Coordinate List out of Sequence ..    $A Note

 Atoms in the CIF are not given in logical order (i.e. C1, C2 etc.)
 The recommended procedure is to sort the atom list in some logical
 order before the final refinement cycles.
#=============================================================================
# >>> Test for O-atom Labels Ordered
_796  0.0  2.0  2.0 4 I   0 0 0 1                              
O-Atom in CIF Coordinate List out of Sequence ..    $A Note

 Atoms in the CIF are not given in logical order (i.e. O1, O2 etc.)
 The recommended procedure is to sort the atom list in some logical
 order before the final refinement cycles.
#=============================================================================
# >>> Test for N-atom Labels Ordered
_797  0.0  2.0  2.0 4 I   0 0 0 1                              
N-Atom in CIF Coordinate List out of Sequence ..    $A Note

 Atoms in the CIF are not given in logical order (i.e. N1, N2 etc.)
 The recommended procedure is to sort the atom list in some logical
 order before the final refinement cycles.
#=============================================================================
# >>> Test for Alphanumeric Label on coordinate record
_798  0.0  2.0  2.0 4 A   0 0 0 1                              
Numeric Atom Label on Coordinate Par. Record ...    $A

 Atom labels are generally not a number (i.e. starting with one or two
 characters indicating the atom type). Labels can be erroneously numeric
 due to typing errors (e.g. 'Oxygen' typed as 'zero').
#=============================================================================
# >>> Test for Alphanumeric Label on displacement par. record
_799  0.0  2.0  2.0 4 A   0 0 0 1                              
Numeric Label on Displacement Par. Record ......    $A

 Atom labels are generally not a number (i.e. starting with one or two
 characters indicating the atom type). Labels can be erroneously numeric
 due to typing errors (e.g. 'Oxygen' typed as 'zero').
#=============================================================================
# >>> Test for out-of-order symmetry data                
_800  0.0  0.0  0.0 4 A   1 0 0 0
Symmetry Specification Should Precede Cell Data.     Please Do!
 
 Symmetry data (i.e. space group, symmetry operations etc.) are expected
 to be given n the CIF prior to the cell dimensions and coordinate data.
#=============================================================================
# >>> Test for missing, incomplete or out-of-order Cell data                
_801  0.0  0.0  0.0 4 A   1 0 0 0 
Cell Data Missing, Incomplete or Out-of-Order        Please Check 
 
 PLATON/CheckCIF has a problem with the Cell data. A possible reason can be
 that the cell data are missing, incomplete or out-of-sequence.
 PLATON/CheckCIF wishes to encounter the cell and symmetry data before any
 coordinates are given. PLATON expects the values of all six cell parameters.
#=============================================================================
# >>> Test for Input lines longer than 80 Characters                
_802    0   10   10 4 I   0 0 0 1     
CIF Input Record(s) with more than 80 Characters          ! Info

 The CIF contains records longer than 80 characters. Not all software will  
 read beyond column 80.
 The CIF-1.1 definition specifies a maximum of 2048 character per record.
#=============================================================================
# >>> Test for Loop problem in CIF-Read                             
_803  0.0  0.0  0.0 1 A   0 0 0 1    
Loop Problem in CIF-Reading (Too Many loop Items)    Please Check

 Fatal Problem: Check loop data names and data for errors. There are 
 likely too many or to few data in the loop.
#=============================================================================
# >>> Test for ARU-Pack Problem(s) in PLATON                           
_804    0    1    1 5 I   0 0 0 1
Number of ARU-Code Packing Problem(s) in PLATON  $I Info  

 Problem: ARU representations turn out to be needed outside the ORTEP
 style -5:5 unit-cell translation range. The Analysis might be incomplete.
 The problem often occurs for structures with aliphatic chains stretching
 over many unitcells or network structures. Transformation of the unitcell
 content to a symmetry related position might solve the problem. 
#=============================================================================
# >>> Test for insufficient 'coordinate data'                       
_805    0    0    0 1 A   0 0 0 1
Fatal Problem: Insufficient Data in Atom Loop ..     Please Check

 Check Coordinate Data Loop.
#=============================================================================
# >>> Test for insufficient 'UIJ data'                       
_806    0    2    2 4 A   1 0 0 1
Fatal Problem: Insufficient Data in UIJ Loop ...     Please Check

 Check UIJ Data Loop.
#=============================================================================
# >>> Test for Maximum number of ATOMS Exceeded Problem                         
_807    0    0  100 5 A   0 0 0 1
Fatal Problem: Maximum Number of Atoms Exceeded.          ! Info

 PLATON can handle up to 'NP1' in the (expanded) ATOM list. 
 This might happen with disordered or network structures in high
 symmetry space groups. Deletion of the symmetry information might solve
 part of the problem and provide a partial validation. 
 Alternatively, clicking on 'NOSYMM' on the PLATON menu before invoking
 validation might address the problem.
#=============================================================================
# >>> Test for Parseable SHELXL style Weighting scheme        
_808    0    0    0 5 A   0 0 0 1 
No Parseable SHELXL Style Weighting Scheme Found     Please Check

 The software did not succeed in finding/analyzing a parsable weighting 
 scheme.      

 SHELXL style weight parameters are expected to be given in the format: 

 _refine_ls_weighting_details
 'calc w=1/[\s^2^(Fo^2^)+(0.1000P)^2^+0.0000P] where P=(Fo^2^+2Fc^2^)/3'

 JANA style weight is expected to be given in the format:

 _refine_ls_weighting_details 'w=1/(\s^2^(I)+0.0016I^2^)'  


  Do not edit this string or make it into a text block between ';'. 
#=============================================================================
# >>> Test the SHELXL style Weighting scheme        
_809    0    0    0 1 A   0 0 0 1 
Can not Parse the SHELXL Weighting Scheme String     Please Check

 The software did not succeed in Parsing the SHELXL style weighting 
 scheme. The string might have been edited or of the more than 2 parameter
 variety (see SHELXL manual).
#=============================================================================
# >>> Test for Out-of-Memory Problem                         
_810    0    0    0 5 A   0 0 0 1
Out-of-Memory Problem in PLATON/ASYM ...........          ! Info

 Analysis for missing reflections may be incomplete due to an out-of-memory
 problem.
#=============================================================================
# >>> Test for No ADDSYM Analysis                            
_811    0    2    2 5 A   0 0 0 1
No ADDSYM Analysis: Too Many Excluded Atoms ....          ! Info

 The ADDSYM test for missed symmetry is not executed for structures with too
 many disordered atoms. 
#=============================================================================
# >>> Test for ALIAS OVERFLOW                                
_812    0    0    2 5 A   0 0 0 1
PLATON problem - Too many Aliased Atoms. Max =   $I    

 Non-standard labels are aliased into acceptable labels. The maximum number 
 of aliases is reached. 
#=============================================================================
# >>> Test for insufficient data on HKLF record in CIF              
_813    0    0    0 1 A   0 0 0 1
No Numerical Data in HKLF (.res) Record in CIF .     Please Check

 Check the HKLF record in the SHELXL style .res is embedded in the CIF.
 This Record should show either 'HKLF 4' or 'HKLF 5'.
 The information in this record is used to establish that a twinning model
 was refined. 
#=============================================================================
# >>> Test fot (In)Commensurate Structure CIF
_814    0    0    0 5 A   0 0 0 1
No Validation of (In)commensurate Structure CIFs            Note

 PLATON/CheckCIF can not validate the CIFs associated with (in)commensurate
 structure reports. 
#=============================================================================
# >>> Report Read Problem in PLATON/PLA230                                
_820    0    0    0 5 A   0 0 0 1
Internal PLATON Read Problem with ALERT Number .    $A

 Internal PLATON Problem. Please refer problem to author at a.l.spek@uu.nl
#=============================================================================
# >>> Test for BASF/TWIN Problem in SHELXL                          
_850  0.0  2.0  2.0 4 A   0 0 0 1
Check Flack Parameter Exact Value 0.00 and su .. $F Check

 This G_ALERT can be ignored in the case that the so-called 'on-the-cheap' 
 Flack parameter is reported as determined with SHELXL. 

 Exactly zero values are possible but may also be a software artefact.

 The following should be checked:
 
 Problem #1: Some SHELXL97 versions do not allow negative values of the
 Flack parameter when determined using the BASF/TWIN instructions.
 Negative values are set to 0.00001. Refinement may not converge completely. 

 Problem #2: Some SHELXL97 versions put meaningless values in the CIF for the
 Flack parameter when 'TWIN -1 0 0 0 -1 0 0 0 -1 2 / BASF' instructions (i.e.
 an explicit matrix is specified on the TWIN instruction) are used.
 Please check the value of BASF (in the list output)  against the Flack
 parameter in the CIF. 	
#=============================================================================
# >>> Test for restraints used in refinement
_860    0    0    0 3 I   0 0 1 0
Number of Least-Squares Restraints ............. $I Note

 The use of restraints used in the refinement should be explained in
 the write-up of a structure analysis.

 It is also recommended to include the refinement instructions in the
 CIF (e.g. the final .res of a SHELXL refinement) as a comment:
 _iucr_refine_instructions_details
 ;
 TITL
 ..
 (etc.)
 ;

 Note: An exception are restraints for floating origins (e.g. in P21).
#=============================================================================
# >>> Report the Suppression of Olex2/_smtbx_masks use Related ALERTS 
_868    0    0    0 4 A   0 0 0 1
ALERTS Due to the use of _smtbx_masks Suppressed          ! Info

 ALERTS related to the use of Olex2/_smtbx_masks that can not (yet) be
 accounted for as part of the VALIDATION algorithms have been suppressed.
#=============================================================================
# >>> Report the Suppression of SQUEEZE use Related ALERTS 
_869    0    0    0 4 A   0 0 0 1
ALERTS Related to the use of SQUEEZE Suppressed           ! Info

 ALERTS related to the use of PLATON/SQUEEZE that can not (yet) be accounted
 for as part of the VALIDATION algorithms have been suppressed.
#=============================================================================
# >>> Report the Suppression of some Twinning Related ALERTS 
_870    0    0    0 4 A   0 0 0 1
ALERTS Related to Twinning Effects Suppressed ..          ! Info

 ALERTS related to twinning effects that can not (yet) be accounted
 for as part of the VALIDATION algorithms have been suppressed.
#=============================================================================
# >>> Report the Suppression of some Laue technique related ALERTS
_871    0    0    0 4 A   0 0 0 1
Laue technique Related ALERTS are Suppressed ...          ! Info

 ALERTS related to the use of the Laue technique with a wavelength   
 range have been suppressed.
#=============================================================================
# >>> Report the Use of an older SHELXL version                    
_899    0    0    0 4 A   0 0 0 1
SHELXL97   is Deprecated and Succeeded by SHELXL $I Note

 A more recent SHELXL version is now available. Final refinement with the
 latest version is recommended.
#=============================================================================
# >>> Test for 'No-matching reflection file'
_900    0    0    0 1 I   0 0 0 1
No Matching Reflection File (FCF) Found ........    Please Check

 Likely cause: Dataset names in the CIF and FCF differ.

 Note: FCF Validation is Skipped for this Entry.
#=============================================================================
# >>> Test for CIF & FCF CELL Not Matching  
_901    0    0    0 1 I   0 0 0 1
Cell Parameters in CIF and FCF do not Match ....          ! Error

 Possible causes: wrong dataset, CIF or FCF parameters edited inconsistently 
 or cell parameters for transformed cell (e.g. P21/n <-> P21/c).

 Note: FCF Validation is Skipped for this Entry.
#=============================================================================
# >>> Test for non-zero number of recognised reflections in FCF
_902    0    0    0 1 I   0 0 0 1
No (Interpretable) Reflections found in FCF ....     Please Check

 Either no reflections are found in the FCF or the FCF is uninterpretable 
 due to unknown format or editing.

 Note: FCF Validation is Skipped for this Entry.
#=============================================================================
# >>> Test for Fobs=Fcalc in FCF                               
_903    0    0    0 1 I   0 0 0 1
F(obs) and F(calc) values are identical in FCF .     Please Check

 Check the FCF file for F(obs) equal F(calc) [of F(obs)**2 equal F(calc)**2]. 
#=============================================================================
# >>> Test for NREF .GT. NPAR in the CIF                                 
_904    0    0    0 1 I   0 0 0 1
Number of Reflections is <  number of Parameters $I       

 The number of reflections found in the reflection file is less than
 the number of parameters reported in the CIF.
#=============================================================================
# >>> Report Negative K values in the Analysis of Variance
_905  0.0  1.0  2.0 3 I   0 0 1 0
Negative K value in the Analysis of Variance ... $F Report

 Scale Factors (i.e. K = Mean[Fo**2] / Mean [Fc**2]) for selected groups of
 reflections, as listed in the Analysis of Variance Section #7 of the FCF 
 validation report, are expected to have a value of about 1.000. Strong
 deviations should be investigated, acted upon or explained.
 (see also SHELXL manual). A reason can be meaningless (weak) high order
 data where a cut-back of the resolution might be indicated. Incorrect
 background treatment can lead to numerous negative observed intensities
 for weak reflections (i.e. F(calc) close to zero.
 For details see the Analysis-of-Variance Section in the '.ckf' file.
#=============================================================================
# >>> Report Large K values in the Analysis of Variance
_906  0.0  1.0  2.0 3 I   0 0 1 0
Large K value in the Analysis of Variance ...... $F Check

 Scale Factors (i.e. K = Mean[Fo**2] / Mean [Fc**2]) for selected groups of
 reflections, as listed in the Analysis of Variance Section #7 of the FCF 
 validation report, are expected to have a value of about 1.000. Strong
 deviations should be investigated, acted upon or explained.
 (see also SHELX manual). 
 For details see the Analysis-of-Variance Section in the '.ckf' file.
#=============================================================================
# >>> Report on Max Observed data in any Resolution Shell
_908    0    0    0 2 A   0 0 0 1
Max. Perc. Data with I > 2*s(I) per Res.Shell .  $F %    

 A low maximum percentage of reflections with I > 2*s(I) may indicate:
 1 - Missed translation symmetry. E.g. all reflections hkl weak
     for l = 2n +1
 2 - Pseudo-merohedral twinning, index > 1. (e.g. non-spacegroup
     extinctions.
 3 - Very weak observed data.
#=============================================================================
# >>> Report of Observed data at Theta Cutoff     
_909    0    0    0 3 A   0 1 0 0
Percentage of Observed Data at Theta(Max) still  $I %     

 This ALERT Reports on whether there is still a significant level of
 observed data beyond the Theta cutoff of the Dataset. There should
 be a good reason for a cutoff below sin(theta)/lambda = 0.6. 
#=============================================================================
# >>> Test for missing reflections below Theta-Min
_910    0   10   50 3 A   0 0 0 1
Missing # of FCF Reflection(s) Below Th(Min) ... $I Report

 Possible causes: Beamstop theta-min limit set too high, large unit-cell etc.
 A possible technical solution on CCD based equipment involves the collection 
 of additional images with the detector at a larger distance from the 
 crystal with the beamstop setting changed accordingly..
#=============================================================================
# >>> Test for missing reflections between Theta-Min and sinth/lambda=0.6
_911   -1    5  999 3 A   0 0 0 1
Missing # FCF Refl Between THmin & STh/L=$A $I Report

 Possible causes: Missing cusp of data (due to rotation about one axis),
 deleted (overflow) reflections or improper strategy (orthorhombic for
 monoclinic crystal etc.) 
#=============================================================================
# >>> Test for missing reflections above Sin(TH)/Lambda = 0.6
_912   -1  100  999 4 A   0 0 0 1
Missing # of FCF Reflections Above STh/L=  0.600 $I Note

 Possible causes: Missing cusp of data (due to rotation about one axis),
 deleted (overflow) reflections or improper strategy (orthorhombic for
 monoclinic crystal etc.) 
#=============================================================================
# >>> Test for missing strong reflections                       
_913    0  100  999 3 A   0 0 0 1
Missing # of Very Strong Reflections in FCF .... $I Note

 This ALERT reports the number of missing reflections with Fc**2 values
 greater than the largest Fc**2 value in the FCF. 
 Possible causes: Missing cusp of data (due to rotation about one axis),
 deleted (overflow) reflections or improper strategy (orthorhombic for
 monoclinic crystal etc.) or behind the beamstop. 
#=============================================================================
# >>> Test for absence of Bijvoet Pairs in non-centro structure     
_914    0    2    2 3 A   0 0 0 1
No Bijvoet Pairs in FCF for Non-centro Structure     Please Check

 This ALERT reflects the notion that a dataset should contain a sufficient
 number of Bijvoet (Friedel) pairs for the reliable determination of the
 absolute structure of a non-centrosymmetric crystal structure. 

 This test is invoked when a Flack parameter value is specified.
 Note: SHELXL97 will calculate/report a Flack parameter value even for
 refinement against Friedel merged data. Remove the Flack entry from the 
 CIF.
#=============================================================================
# >>> Test for low Friedel Pair Coverage in non-centro structure     
_915  10.  50.  100 3 A   0 0 0 1
Low Friedel Pair Coverage ...................... $I %    

 This ALERT reflects the notion that a dataset should contain a sufficient
 number of Bijvoet (Friedel) pairs for the reliable determination of the 
 absolute structure of a non-centrosymmetric crystal structure. 

 A Friedel coverage that deviates significantly from 100 percent may
 bias/invalidate the value of the Flack parameter.
#=============================================================================
# >>> Test for differing Flack x and Hooft y Parameter values        
_916  0.1  0.2  0.3 2 A   0 0 0 1
Hooft y and Flack x Parameter values differ by . $F Check

 The Hooft y Parameter is calculated independently from the Bijvoet 
 differences and should have a value similar (observing the s.u.'s) to that of
 the Flack x Parameter. 
 See:
 Hooft, R.W.W, Straver, L.H. & Spek,A.L. (2008). J. Appl, Cryst. 41, 96-103.
 Thompson,A.L. & Watkin, D.J. (2009). Tetrahedron: Asymmetry,
   doi:10.1016/j.tetasy.2009.02.025

 Large differences may arise in cases where the Flack parameter was not
 done with BASF/TWIN or with essentially centrosymmetric data.
 See:
 Flack, H.D., Bernardinelli, G, Clemente, D.A., Linden, A. Spek, A.L. (2006)
 Acta Cryst. B62, 695-701.
#=============================================================================
# >>> Test/Report whether FCF is based on a BASF/TWIN refinement        
_917  0.0  0.0  0.0 2 A   0 0 0 1
The FCF is likely NOT based on a BASF/TWIN Flack     Please Check      

 The contribution of F(-h,-k,-l) to F(h,k,l) is likely not included in the
 FCF file. This usually indicates that the Flack parameter was NOT determined
 with a BASF/TWIN type of refinement. 
#=============================================================================
# >>> Test for reflections with I(obs) << I(calc)                       
_918    0  999  999 3 A   0 0 0 1
Reflection(s) with I(obs) much smaller I(calc) . $I Check

 This ALERT reports on the number of reflections with  
 (Fo**2 - Fc**2) / Sigma(Fo**2) < - 100.0. In case of strong reflections this
 might be due to extinction (to be addressed with the refinement of an 
 extinction parameter. Otherwise Those reflections are better removed from
  the final refinement since they are in systematic error.
 Of course, a valid reason for this problem should be found.
#=============================================================================
# >>> Test for reflections effected by the beamstop                     
_919    0    0  999 3 A   0 0 0 1
Reflection # Likely Affected by the Beamstop ... $I Check

 This ALERT reports the number of reflections with intensities seriously 
 effected by the beamstop. Reflections are counted for which theta < 3 
 Degrees and (Fo**2 - Fc**2) / sqrt(weight) < - 10.0. Those reflections 
 are better removed from the final refinement since they are in systematic
 error.
#=============================================================================
# >>> Test for TH(Max) Consistency between CIF & FCF         
_920  .10  .50  1.0 1 A   0 0 0 1
Theta(Max)  in CIF and FCF Differ by ........... $F Degree

 Check reflection statistics of the data in the FCF for consistency with 
 the data reported in the CIF.     

 A difference usually indicates an edited CIF or an FCF file that was
 not created in the same SHELXL run where the CIF was created.
#=============================================================================
# >>> Test for R1 Consistency between CIF & FCF(Reported)         
_921 .001 .005 .050 1 A   0 0 0 1
R1  in the CIF and FCF Differ by ............... $F Check

 Please check whether the supplied FCF corresponds with the CIF produced in 
 the same least squares refinement job.      

 The test is based on the observed and calculated F**2 in the FCF and de
 weight parameters taken from the CIF.
#=============================================================================
# >>> Test for wR2 Consistency between CIF & FCF(Reported)         
_922 .001 .005 .050 1 A   0 0 0 1
wR2 in the CIF and FCF Differ by ............... $F Check

 Please check whether the supplied FCF corresponds with the CIF produced in 
 the same least squares refinement job.     

 The test is based on the observed and calculated F**2 in the FCF and de
 weight parameters taken from the CIF.
#=============================================================================
# >>> Test for S Consistency between CIF & FCF(Reported)         
_923  .01  .50  1.0 1 A   0 0 0 1
S    values in the CIF and FCF Differ by ....... $F Check

 Please check whether the supplied FCF corresponds with the CIF produced in 
 the same least squares refinement job.     

 The test is based on the observed and calculated F**2 in the FCF and de
 weight parameters taken from the CIF.
#=============================================================================
# >>> Test for Consistency of the  Reported & Calculated  Rho(min)  
_924  1.0  2.0  3.0 1 A   0 0 0 1
The Reported and Calculated Rho(min) Differ by . $F eA-3

 Check & Explain why the Reported Rho(min) differs significantly from 
 the value calculated on the basis of the reported structure.     

 Note: The Reported and Calculated values may differ slightly due to
 a differing peak interpolation algorithm.
#=============================================================================
# >>> Test for  Consistency of the Reported & Calculated Rho(max)         
_925  1.0  2.0  3.0 1 A   0 0 0 1
The Reported and Calculated Rho(max) Differ by . $F eA-3 

 Check & Explain why the Reported Rho(max) differs significantly from 
 the value calculated on the basis of the reported structure.     

 Note: The Reported and Calculated values may differ slightly due to
 a differing peak interpolation algorithm.
#=============================================================================
# >>> Test for R1 Consistency between CIF & FCF(Calculated)         
_926 .001 .005 .050 1 A   0 0 0 1
Reported and Calculated   R1 Differ by ......... $F Check

 Please check whether the R1 value that is reported in the CIF corresponds
 with the R1 value calculated from the parameters supplied in the CIF.

 This test is based on the observed reflection data in the FCF and 
 reflection data that are calculated with the parameters (i.e. coordinates,
 displacement and weight parameters) taken from the CIF.
#=============================================================================
# >>> Test for wR2 Consistency between CIF & FCF(Calculated)
_927 .001 .005 .050 1 A   0 0 0 1
Reported and Calculated  wR2 Differ by ......... $F Check

 Please check whether the wR2 value that is reported in the CIF corresponds
 with the wR2 value calculated from the parameters supplied in the CIF. 

 This test is based on the observed reflection data in the FCF and 
 reflection data that are calculated with the parameters (i.e. coordinates,
 displacement and weight parameters) taken from the CIF.
#=============================================================================
# >>> Test for S Consistency between CIF & FCF(Calculated)
_928  .10  .20 2.00 1 A   0 0 0 1
Reported and Calculated    S value   Differ by . $F  

 Please check whether the S value that is reported in the CIF corresponds
 with the S value calculated from the parameters supplied in the CIF. 

 This test is based on the observed reflection data in the FCF and 
 reflection data that are calculated with the parameters (i.e. coordinates,
 displacement and weight parameters) taken from the CIF.
#=============================================================================
# >>> Test for interpretable weight parameters for R1,wR2 & S Comparison       
_929    0   10   10 5 A   0 0 0 1
No Weight Pars,Obs and Calc R1,wR2,S not checked          ! Info 

 SHELXL weight parameters are expected to be given in the format below: 

 _refine_ls_weighting_details
 'calc w=1/[\s^2^(Fo^2^)+(0.1000P)^2^+0.0000P] where P=(Fo^2^+2Fc^2^)/3'

 JANA style weight is expected to be given in the format:

 _refine_ls_weighting_details 'w=1/(\s^2^(I)+0.0016I^2^)'  

  Do not edit this string or make it into a text block between ';'. 
#=============================================================================
# >>> Test for Missed Twinning from FCF data                              
_930  .00  .00  .80 2 A   0 0 1 0
Check Twin Law ($A)[$B] Estimated BASF $F

 Check the proposed Twin Law. The entry in () represents the proposed 
 rotation axis in reciprocal space and the one in [] the corresponding
 rotation is direct space. 
 The relevant Twin Matrix can be found in the file '.ckf'.

 Note: This analysis is based on Fo/Fc differences with Fc data given
 in the .fcf file (i.e. Fobs, Fcalc listing). 
 
 ALERT-930 is expected to generate an related ALERT-931 as well.
#=============================================================================
# >>> Test for Missed Twinning from FCF/CIF data                              
_931  .00  .00  .80 5 A   0 0 1 0
Found Twin Law ($A)[$B] Estimated BASF $F Check

 Check the proposed Twin Law. The entry in () represents the proposed 
 rotation axis in reciprocal space and the one in [] the corresponding
 rotation is direct space. 
 The relevant Twin Matrix can be found in the file '.ckf'.

 Note: This test is based on F(calc) values calculated with the data
 in the CIF. This ALERT can be ignored when twinning has been addressed
 in the refinement (As indicated by the Absence of ALERT 930).

 Please check whether twinning is mentioned in the write-up of the
 paper.
#=============================================================================
# >>> Report number of outliers                                         
_934    0    1   10 3 A   0 0 1 0
Number of (Iobs-Icalc)/SigmaW > 10 Outliers .... $I Check

 This ALERT reports on the number of reflections for which I(obs) and I(calc)
 differ more that 10 times SigmaW. (The latter being the square root of 
 1.0/weight for that reflection in the L.S. refinement). The reason for those 
 deviations should be investigated. When shown to be systematic errors,
 those reflections are best removed from the refinement and their omission
 from the refinement reported in the experimental section of an associated
 paper.
#=============================================================================
# >>> Pseudo Extinction Parameter Test                      
_935  .05 1.00 2.00 2 A   0 0 0 0
Large Value of Calc. Pseudo Extinction Parameter $F
  
 Both significantly positive and significantly negative values should
 invoke a search for a likely cause and a corrective action.
#=============================================================================
# >>> Test for DAMP instruction in embedded RES
_936    0  0.5    1 2 A   0 0 1 0
The Embedded RES File Includes a DAMP Command .. $F Report

 The reason for the use of a DAMP instruction in the final refinement job
 should be discussed/reported. 'DAMP 0.0' should not be used for small 
 molecule refinement since it masks non-convergence. 
#=============================================================================
# >>> Report Exponential Term in SHELXL weight expression
_937    0 10.0 20.0 4 A   0 0 1 0
Weight Expression Contains Exponential Term .... $F Report

 The use of an exponential term in the SHELXL weight expression is not
 recommended in the final refinement stage (i.e. the third parameter in the
 SHELXL WGHT record).
#=============================================================================
# >>> Test for high not weight optimized S value            
_939 10.0 100. 500. 3 A   0 0 0 1
Large Value of Not (SHELXL) Weight Optimized S . $F
  
 SHELXL optimizes two weight parameters to bring the S value close to
 1.0. This ALERT reports the S value based on the supplied sigma(I)
 only. A large value of the last generally indicates the presence of
 large outliers in the data set. Examples are reflections 'measured'
 behind the beam stop. (See also ALERT_919). The latter are best left
 out with an OMIT instruction.
#=============================================================================
# >>> Test for wR2 refinement with all data         
_940    0    0    2 3 A   0 0 0 1
F**2 Refinement with I < n * Sigma(I) only .....     Please Check  

 Apparently, observed data with I > n * sigma(I) were used in the F**2
 least squares refinement, rather than all observed data. 
#=============================================================================
# >>> Test for Reported and Calculated Hmax Difference (From CIF Data)
_950    0  100  200 5 I   0 0 0 1
Calculated (ThMax) and CIF-Reported Hmax Differ  $I Units         

 Reported (in the CIF) and Calculated (from Theta-max in CIF) Max(Hmax,-Hmin)
 values differ by at least one unit. Check the consistency of wavelength and
 reported resolution data items. 
#=============================================================================
# >>> Test for Reported and Calculated Kmax Difference (From CIF Data)
_951    0  100  200 5 I   0 0 0 1
Calculated (ThMax) and CIF-Reported Kmax Differ  $I Units         

 Reported (in the CIF) and Calculated (from Theta-max in CIF) Max(Kmax,-Kmin)
 values differ by at least one unit. Check the consistency of wavelength and
 reported resolution data items.
#=============================================================================
# >>> Test for Reported and Calculated Lmax Difference (From CIF Data)
_952    0  100  200 5 I   0 0 0 1
Calculated (ThMax) and CIF-Reported Lmax Differ  $I Units   

 Reported (in the CIF) and Calculated (from Theta-max in CIF)  Max(Lmax,-Lmin)
 values differ by at least one unit. Check the consistency of wavelength and
 reported resolution data items.
#=============================================================================
# >>> Test for Reported (in CIF) and Actual Hmax Difference in the FCF File
_953    1  999  999 1 I   0 0 0 1
Reported (CIF) and Actual (FCF) Hmax Differ by . $I Units   

 Reported (in the CIF) and Actual (in the FCF)  Max(Hmax,-Hmin) values
 differ by more than one unit. Check for data set truncation.
#=============================================================================
# >>> Test for Reported (in CIF) and Actual Kmax Difference in the FCF File
_954    1  999  999 1 I   0 0 0 1
Reported (CIF) and Actual (FCF) Kmax Differ by . $I Units   

 Reported (in the CIF) and Actual (in the FCF) Max(Kmax,-Kmin) values
 differ by more than one unit. Check for data set truncation.
#=============================================================================
# >>> Test for Reported (in CIF) and Actual Lmax Difference in the FCF file
_955    1  999  999 1 I   0 0 0 1
Reported (CIF) and Actual (FCF) Lmax Differ by . $I Units   

 Reported (in the CIF) and Actual (in the FCF) Max(Lmax,-Lmin) values
 differ by more than one unit. Check for data set truncation.
#=============================================================================
# >>> Test for Calculated (Theta-max) and Actual Hmax Difference in the FCF File
_956    1  999  999 1 I   0 0 0 1
Calculated (ThMax) and Actual (FCF) Hmax Differ  $I Units

 Calculated (From Theta-Max in the CIF) and Actual (in the FCF) Max(Hmax,-Hmin)
 values differ by more than one unit. Check for data set truncation.
#=============================================================================
# >>> Test for Calculated (Theta-max) and Actual Kmax Difference in the FCF File
_957    1  999  999 1 I   0 0 0 1
Calculated (ThMax) and Actual (FCF) Kmax Differ  $I Units

 Calculated (From Theta-Max in the CIF) and Actual (in the FCF) Max(Kmax,-Kmin)
 values differ by more than one unit. Check for data set truncation.
#=============================================================================
# >>> Test for Calculated (Theta-max) and Actual Lmax Difference in the FCF file
_958    1  999  999 1 I   0 0 0 1
Calculated (ThMax) and Actual (FCF) Lmax Differ  $I Units 

 Calculated (From Theta-max in the CIF) and Actual (in the FCF) Max(Lmax,-Lmin)
 values differ by more than one unit. Check for data set truncation.
#=============================================================================

# >>> Test for reflections with I <  - 2 sigma                     
_960    0    0  999 3 A   0 0 0 1
Number of Intensities with I  <   - 2*sig(I) ... $I Check

 Multiple strongly negative intensities may be indicative for poor 
 integration of the  diffraction images. 
 Too many negative intensities may result in higher than usual wR2 values.
#=============================================================================
# >>> Test for absence of negative observed intensities            
_961    0    0    0 5 A   0 0 0 1 
Dataset Contains no Negative Intensities .......     Please Check 

 Generally, both positive and slightly negative intensities are expected
 in a data set. Resetting negative intensities to zero may bias the
 refinement results and the 'analysis-of-variance' as reported e.g. in
 the SHELXL output listing.
#=============================================================================
# >>> Test for Input Reflections with Sig(Fo^2) = 0                
_962    0    0    1 5 A   0 0 0 1
Number of Input Relections with Sigma(Fo^2) =  0 $I        

 Reflections with Sigma(Fo^2) = 0 are suspect and best left out of the
 refinement.
 This type of reflections will result in multiple R & S-value difference
 ALERTS.
#=============================================================================
# >>> Test for large positive calculated residual density  
_971 1.50 2.50 3.50 2 A   0 0 1 0
Check Calcd Residual Density$B From $A $F eA-3

 Larger than expected residual density maximum outside metal atom locations.
 This might be caused by unaccounted for twinning, wrongly assigned 
 atom types, unaccounted for solvent and other model errors. 
#=============================================================================
# >>> Test for large negative calculated residual density 
_972 1.50 2.50 3.50 2 A   0 0 1 0
Check Calcd Residual Density$B From $A $F eA-3

 Larger than expected residual density minimum outside metal atom locations. 
 This might be caused by unaccounted for twinning, wrongly assigned 
 atom types and other model errors.
#=============================================================================
# >>> Test for large positive density on metal atom  
_973 1.00  1.5  2.0 2 A   0 0 1 0 
Check Calcd Positive Residual Density on $A $F eA-3

 Larger than expected residual density maximum on metal atom location. 
 This might be caused by unaccounted for twinning, wrongly assigned 
 atom types and other model errors.
 Another cause may be a SHELXL 'DAMP 0 0' instruction for a non-converged
 refinement.
#=============================================================================
# >>> Test for large negative density close to metal atom
_974 1.00  1.5  2.0 2 A   0 0 1 0
Check Calcd Negative Residual Density on $A $F eA-3

 Larger than expected residual density minimum on metal atom location. 
 This might be caused by unaccounted for twinning, wrongly assigned 
 atom types and other model errors.
 Another cause may be a SHELXL 'DAMP 0 0' instruction for a non-converged
 refinement.
#=============================================================================
# >>> Test for positive density near N or O
_975 0.30  1.5  2.0 2 A   0 0 1 0
Check Calcd Residual Density$B From $A $F eA-3

 Positive density found in a difference density map at a position 
 within bonding distance for a hydrogen atom from a nitrogen or oxygen
 atom. 

 A possible reason can be a missing hydrogen atom.
 Also check for tautomerism.
#=============================================================================
# >>> Test for negative density near N or O 
_976 0.30  1.5  2.0 2 A   0 0 1 0
Check Calcd Residual Density$B From $A $F eA-3

 Negative density found in a difference density map at a location 
 within bonding distance for a hydrogen atom from a nitrogen or oxygen
 atom.    

 A possible reason can be a misassigned hydrogen atom. 
 Also check for tautomerism.
#=============================================================================
# >>> Test for non-zero number of anomalous scattering factors                  
_980    0    0  999 1 A   0 0 0 1
No Anomalous Scattering Factors Found in CIF ...     Please Check  

 Check for missing anomalous scattering factors.
#=============================================================================
# >>> Test for non-zero f" anomalous scattering factor values           
_981    0    0  999 1 A   0 0 0 1
No non-zero f" Anomalous Scattering Values Found     Please Check 

 Check for non-zero f" anomalous scattering factor values in the CIF.
 Note: Zero values are correct for SHELXL MERG 4 refinements.
#=============================================================================
# >>> Test the anomalous scattering factor f' values against IT          
_982    0    0  999 1 A   0 0 0 1
The$A$F Deviates from the  IT-value    $B Check

 Check the supplied anomalous scattering factor f' value against those
 in the International Tables.
#=============================================================================
# >>> Test the anomalous scattering factor f" values against IT          
_983    0    0  999 1 A   0 0 0 1
The$A$F Deviates from the  IT-Value    $B Check

 Check the supplied anomalous scattering factor f'' value against those
 in the International Tables.
#=============================================================================
# >>> Test the anomalous scattering factor f' values against B&C          
_984    0    0  999 1 A   0 0 0 1
The$A$F Deviates from the B&C-Value    $B Check

 Check the supplied anomalous scattering factor f' value for the
 non Cu, Mo or Ag wavelength against those of Brennan & Cowan.
#=============================================================================
# >>> Test the anomalous scattering factor f" values against B&C         
_985    0    0  999 1 A   0 0 0 1
The$A$F Deviates from the B&C-Value    $B Check

 Check the supplied anomalous scattering factor f'' value for the
 non Cu, Mo or Ag wavelength against those of Brennan & Cowan.
#=============================================================================
# >>> Test for non-zero f' anomalous scattering factor values           
_986    0    0  999 1 A   0 0 0 1
No non-zero f' Anomalous Scattering Values Found     Please Check 

 Check for non-zero f' anomalous scattering factor values in the CIF.
#=============================================================================
# >>> Test for the need of a TWIN/BASF refinement           
_987    0    0  999 1 A   0 0 0 1
The Flack x is >> 0 -  Do a BASF/TWIN Refinement     Please Check 

 A BASF/TWIN refinement of the Flack x parameter is indicated when this value
 deviates significantly from zero and the structure contains significant
 anomalous scatterers.
#=============================================================================
# >>> Test for Acceptable CIF/FCF file Combination for SHELXL            
_997    0    0    0 1 A   0 0 0 1 
Unsuitable CIF/FCF File Combination with SHELXL CIF       ! Error 

 The CIF file reports refinement with SHELXL whereas the supplied reflection
 file is not of the SHELXL LIST 4 or LIST 8 type.
 Proper FCF validation is not possible with the alternative LIST options.
#=============================================================================
# >>> Test for LIST3                                                     
_998    0    0    0 1 A   0 0 0 1 
SHELXL LIST 3 Fo/Fc Unsuitable for FCF-Validation .       ! Error 

 IUCr CheckCIF validation requires SHELXL/LIST 4, LIST 8 or Equivalent 
 Fo**2,Fc**2, sigma(Fo**2)  reflection files.                                  
#=============================================================================
# >>> Test for LIST6                                                     
_999    0    0    0 1 A   0 0 0 1
SHELXL LIST 6 Fo/Fc Unsuitable for FCF-Validation .       ! Error 

 IUCr CheckCIF validation requires SHELXL/LIST 4, LIST 8 or Equivalent 
 Fo**2,Fc**2, sigma(Fo**2)  reflection files.                                  
#=============================================================================
$ END-OF-SECTION
